@@ -556,6 +556,16 @@ func (r *ProtocolIncus) CreateImage(image api.ImagesPost, args *ImageCreateArgs)
 		req.Header.Set("X-Incus-profiles", imgProfiles.Encode())
 	}
 
+	if len(image.Aliases) > 0 {
+		imgProfiles := url.Values{}
+
+		for _, v := range image.Aliases {
+			imgProfiles.Add("alias", v.Name)
+		}
+
+		req.Header.Set("X-Incus-aliases", imgProfiles.Encode())
+	}
+
 	// Set the user agent
 	if image.Source != nil && image.Source.Fingerprint != "" && image.Source.Secret != "" && image.Source.Mode == "push" {
 		// Set fingerprint
@@ -738,8 +748,12 @@ func (r *ProtocolIncus) CopyImage(source ImageServer, image api.Image, args *Ima
 			},
 		}
 
+		imagesPost.Aliases = args.Aliases
 		if args.CopyAliases {
 			imagesPost.Aliases = image.Aliases
+			if args.Aliases != nil {
+				imagesPost.Aliases = append(imagesPost.Aliases, args.Aliases...)
+			}
 		}
 
 		imagesPost.ExpiresAt = image.ExpiresAt
@@ -764,7 +778,6 @@ func (r *ProtocolIncus) CopyImage(source ImageServer, image api.Image, args *Ima
 			Target:      info.URL,
 			Certificate: info.Certificate,
 			Secret:      secret.(string),
-			Aliases:     image.Aliases,
 			Project:     info.Project,
 			Profiles:    image.Profiles,
 		}
@@ -832,6 +845,7 @@ func (r *ProtocolIncus) CopyImage(source ImageServer, image api.Image, args *Ima
 		imagePost.Public = args.Public
 		imagePost.Profiles = image.Profiles
 
+		imagePost.Aliases = args.Aliases
 		if args.CopyAliases {
 			imagePost.Aliases = image.Aliases
 			if args.Aliases != nil {
@@ -877,6 +891,19 @@ func (r *ProtocolIncus) CopyImage(source ImageServer, image api.Image, args *Ima
 				rop.err = remoteOperationError("Failed to copy image", nil)
 				return
 			}
+
+			// Apply the aliases.
+			for _, entry := range imagePost.Aliases {
+				alias := api.ImageAliasesPost{}
+				alias.Name = entry.Name
+				alias.Target = image.Fingerprint
+
+				err := r.CreateImageAlias(alias)
+				if err != nil {
+					rop.err = remoteOperationError("Failed to add alias", nil)
+					return
+				}
+			}
 		}()
 
 		return &rop, nil
