@@ -3,7 +3,7 @@ package incus
 import (
 	"fmt"
 
-	"github.com/lxc/incus/shared/api"
+	"github.com/lxc/incus/v6/shared/api"
 )
 
 // GetMetadataConfiguration returns a configuration metadata struct.
