@@ -6,7 +6,10 @@ import (
 	"encoding/json"
 	"fmt"
 	"io"
+	"net/http"
+	"net/url"
 	"os"
+	"os/exec"
 	"path/filepath"
 	"strings"
 	"time"
@@ -30,6 +33,21 @@ type ociInfo struct {
 	} `json:"LayersData"`
 }
 
+// Get the proxy host value.
+func (r *ProtocolOCI) getProxyHost() (*url.URL, error) {
+	req, err := http.NewRequest("GET", r.httpHost, nil)
+	if err != nil {
+		return nil, err
+	}
+
+	proxy, err := r.http.Transport.(*http.Transport).Proxy(req)
+	if err != nil {
+		return nil, err
+	}
+
+	return proxy, nil
+}
+
 // Image handling functions
 
 // GetImages returns a list of available images as Image structs.
@@ -56,6 +74,11 @@ func (r *ProtocolOCI) GetImagesWithFilter(filters []string) ([]api.Image, error)
 func (r *ProtocolOCI) GetImage(fingerprint string) (*api.Image, string, error) {
 	info, ok := r.cache[fingerprint]
 	if !ok {
+		_, err := exec.LookPath("skopeo")
+		if err != nil {
+			return nil, "", fmt.Errorf("OCI container handling requires \"skopeo\" be present on the system")
+		}
+
 		return nil, "", fmt.Errorf("Image not found")
 	}
 
@@ -66,6 +89,7 @@ func (r *ProtocolOCI) GetImage(fingerprint string) (*api.Image, string, error) {
 				"architecture": info.Architecture,
 				"type":         "oci",
 				"description":  fmt.Sprintf("%s (OCI)", info.Name),
+				"id":           info.Alias,
 			},
 		},
 		Aliases: []api.ImageAlias{{
@@ -92,8 +116,28 @@ func (r *ProtocolOCI) GetImage(fingerprint string) (*api.Image, string, error) {
 func (r *ProtocolOCI) GetImageFile(fingerprint string, req ImageFileRequest) (*ImageFileResponse, error) {
 	ctx := context.Background()
 
+	// Get proxy details.
+	proxy, err := r.getProxyHost()
+	if err != nil {
+		return nil, err
+	}
+
+	var env []string
+	if proxy != nil {
+		env = []string{
+			fmt.Sprintf("HTTPS_PROXY=%s", proxy),
+			fmt.Sprintf("HTTP_PROXY=%s", proxy),
+		}
+	}
+
+	// Get the cached entry.
 	info, ok := r.cache[fingerprint]
 	if !ok {
+		_, err := exec.LookPath("skopeo")
+		if err != nil {
+			return nil, fmt.Errorf("OCI container handling requires \"skopeo\" be present on the system")
+		}
+
 		return nil, fmt.Errorf("Image not found")
 	}
 
@@ -106,6 +150,11 @@ func (r *ProtocolOCI) GetImageFile(fingerprint string, req ImageFileRequest) (*I
 		return nil, fmt.Errorf("OCI image export currently requires root access")
 	}
 
+	_, err = exec.LookPath("umoci")
+	if err != nil {
+		return nil, fmt.Errorf("OCI container handling requires \"umoci\" be present on the system")
+	}
+
 	// Get some temporary storage.
 	ociPath, err := os.MkdirTemp("", "incus-oci-")
 	if err != nil {
@@ -114,12 +163,12 @@ func (r *ProtocolOCI) GetImageFile(fingerprint string, req ImageFileRequest) (*I
 
 	defer func() { _ = os.RemoveAll(ociPath) }()
 
-	err = os.Mkdir(filepath.Join(ociPath, "oci"), 0700)
+	err = os.Mkdir(filepath.Join(ociPath, "oci"), 0o700)
 	if err != nil {
 		return nil, err
 	}
 
-	err = os.Mkdir(filepath.Join(ociPath, "image"), 0700)
+	err = os.Mkdir(filepath.Join(ociPath, "image"), 0o700)
 	if err != nil {
 		return nil, err
 	}
@@ -129,11 +178,15 @@ func (r *ProtocolOCI) GetImageFile(fingerprint string, req ImageFileRequest) (*I
 		req.ProgressHandler(ioprogress.ProgressData{Text: "Retrieving OCI image from registry"})
 	}
 
-	stdout, err := subprocess.RunCommand(
+	stdout, _, err := subprocess.RunCommandSplit(
+		ctx,
+		env,
+		nil,
 		"skopeo",
 		"--insecure-policy",
 		"copy",
-		fmt.Sprintf("%s/%s", strings.Replace(r.httpHost, "https://", "docker://", -1), info.Alias),
+		"--remove-signatures",
+		fmt.Sprintf("%s/%s", strings.Replace(r.httpHost, "https://", "docker://", 1), info.Alias),
 		fmt.Sprintf("oci:%s:latest", filepath.Join(ociPath, "oci")))
 	if err != nil {
 		logger.Debug("Error copying remote image to local", logger.Ctx{"image": info.Alias, "stdout": stdout, "stderr": err})
@@ -171,7 +224,7 @@ func (r *ProtocolOCI) GetImageFile(fingerprint string, req ImageFileRequest) (*I
 		return nil, err
 	}
 
-	err = os.WriteFile(filepath.Join(ociPath, "image", "metadata.yaml"), data, 0644)
+	err = os.WriteFile(filepath.Join(ociPath, "image", "metadata.yaml"), data, 0o644)
 	if err != nil {
 		return nil, err
 	}
@@ -288,8 +341,28 @@ func (r *ProtocolOCI) GetImageAliasNames() ([]string, error) {
 
 // GetImageAlias returns an existing alias as an ImageAliasesEntry struct.
 func (r *ProtocolOCI) GetImageAlias(name string) (*api.ImageAliasesEntry, string, error) {
+	// Get proxy details.
+	proxy, err := r.getProxyHost()
+	if err != nil {
+		return nil, "", err
+	}
+
+	var env []string
+	if proxy != nil {
+		env = []string{
+			fmt.Sprintf("HTTPS_PROXY=%s", proxy),
+			fmt.Sprintf("HTTP_PROXY=%s", proxy),
+		}
+	}
+
 	// Get the image information from skopeo.
-	stdout, err := subprocess.RunCommand("skopeo", "inspect", fmt.Sprintf("%s/%s", strings.Replace(r.httpHost, "https://", "docker://", -1), name))
+	stdout, _, err := subprocess.RunCommandSplit(
+		context.TODO(),
+		env,
+		nil,
+		"skopeo",
+		"inspect",
+		fmt.Sprintf("%s/%s", strings.Replace(r.httpHost, "https://", "docker://", 1), name))
 	if err != nil {
 		logger.Debug("Error getting image alias", logger.Ctx{"name": name, "stdout": stdout, "stderr": err})
 		return nil, "", err
@@ -303,7 +376,7 @@ func (r *ProtocolOCI) GetImageAlias(name string) (*api.ImageAliasesEntry, string
 	}
 
 	info.Alias = name
-	info.Digest = strings.Replace(info.Digest, "sha256:", "", -1)
+	info.Digest = strings.Replace(info.Digest, "sha256:", "", 1)
 
 	archID, err := osarch.ArchitectureId(info.Architecture)
 	if err != nil {
