@@ -1,6 +1,7 @@
 package main
 
 import (
+	"os"
 	"sort"
 
 	"github.com/spf13/cobra"
@@ -26,7 +27,11 @@ func (c *cmdList) Command() *cobra.Command {
 This renders a table with all images currently published on the server.
 `)
 	cmd.RunE = c.Run
-	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", "Format (csv|json|table|yaml|compact)"+"``")
+	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", `Format (csv|json|table|yaml|compact), use suffix ",noheader" to disable headers and ",header" to enable it if missing, e.g. csv,header`+"``")
+
+	cmd.PreRunE = func(cmd *cobra.Command, _ []string) error {
+		return cli.ValidateFlagFormatForListOutput(cmd.Flag("format").Value.String())
+	}
 
 	return cmd
 }
@@ -67,5 +72,5 @@ func (c *cmdList) Run(cmd *cobra.Command, args []string) error {
 		"CREATED",
 	}
 
-	return cli.RenderTable(c.flagFormat, header, data, data)
+	return cli.RenderTable(os.Stdout, c.flagFormat, header, data, images)
 }
