@@ -164,6 +164,8 @@ func (c *cmdClusterGroupAssign) Run(cmd *cobra.Command, args []string) error {
 type cmdClusterGroupCreate struct {
 	global  *cmdGlobal
 	cluster *cmdCluster
+
+	flagDescription string
 }
 
 // Creation of a new cluster group, defining its usage, short and long descriptions, and the RunE method.
@@ -179,6 +181,8 @@ func (c *cmdClusterGroupCreate) Command() *cobra.Command {
 incus cluster group create g1 < config.yaml
 	Create a cluster group with configuration from config.yaml`))
 
+	cmd.Flags().StringVar(&c.flagDescription, "description", "", i18n.G("Cluster group description")+"``")
+
 	cmd.RunE = c.Run
 
 	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
@@ -233,6 +237,10 @@ func (c *cmdClusterGroupCreate) Run(cmd *cobra.Command, args []string) error {
 		ClusterGroupPut: stdinData,
 	}
 
+	if c.flagDescription != "" {
+		group.Description = c.flagDescription
+	}
+
 	err = resource.server.CreateClusterGroup(group)
 	if err != nil {
 		return err
@@ -463,7 +471,11 @@ Pre-defined column shorthand chars:
   m - Member`))
 
 	cmd.Flags().StringVarP(&c.flagColumns, "columns", "c", defaultClusterGroupColumns, i18n.G("Columns")+"``")
-	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G("Format (csv|json|table|yaml|compact)")+"``")
+	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G(`Format (csv|json|table|yaml|compact), use suffix ",noheader" to disable headers and ",header" to enable it if missing, e.g. csv,header`)+"``")
+
+	cmd.PreRunE = func(cmd *cobra.Command, args []string) error {
+		return cli.ValidateFlagFormatForListOutput(cmd.Flag("format").Value.String())
+	}
 
 	cmd.RunE = c.Run
 
