@@ -33,7 +33,10 @@ incus launch images:ubuntu/22.04 u2 -t aws:t2.micro
     Create and start a container using the same size as an AWS t2.micro (1 vCPU, 1GiB of RAM)
 
 incus launch images:ubuntu/22.04 v1 --vm -c limits.cpu=4 -c limits.memory=4GiB
-    Create and start a virtual machine with 4 vCPUs and 4GiB of RAM`))
+    Create and start a virtual machine with 4 vCPUs and 4GiB of RAM
+
+incus launch images:debian/12 v2 --vm -d root,size=50GiB -d root,io.bus=nvme
+    Create and start a virtual machine, overriding the disk size and bus`))
 	cmd.Hidden = false
 
 	cmd.RunE = c.Run
@@ -143,7 +146,12 @@ func (c *cmdLaunch) Run(cmd *cobra.Command, args []string) error {
 			prettyName = fmt.Sprintf("%s:%s", remote, name)
 		}
 
-		return fmt.Errorf("%s\n"+i18n.G("Try `incus info --show-log %s` for more info"), err, prettyName)
+		projectArg := ""
+		if conf.ProjectOverride != "" && conf.ProjectOverride != api.ProjectDefaultName {
+			projectArg = " --project " + conf.ProjectOverride
+		}
+
+		return fmt.Errorf("%s\n"+i18n.G("Try `incus info --show-log %s%s` for more info"), err, prettyName, projectArg)
 	}
 
 	progress.Done("")
