@@ -328,6 +328,8 @@ func (c *cmdNetworkAttachProfile) Run(cmd *cobra.Command, args []string) error {
 type cmdNetworkCreate struct {
 	global  *cmdGlobal
 	network *cmdNetwork
+
+	flagDescription string
 }
 
 func (c *cmdNetworkCreate) Command() *cobra.Command {
@@ -346,6 +348,7 @@ incus network create bar network=baz --type ovn
 
 	cmd.Flags().StringVar(&c.network.flagTarget, "target", "", i18n.G("Cluster member name")+"``")
 	cmd.Flags().StringVarP(&c.network.flagType, "type", "t", "", i18n.G("Network type")+"``")
+	cmd.Flags().StringVar(&c.flagDescription, "description", "", i18n.G("Network description")+"``")
 
 	cmd.RunE = c.Run
 
@@ -399,6 +402,10 @@ func (c *cmdNetworkCreate) Run(cmd *cobra.Command, args []string) error {
 	network.Name = resource.name
 	network.Type = c.network.flagType
 
+	if c.flagDescription != "" {
+		network.Description = c.flagDescription
+	}
+
 	if network.Config == nil {
 		network.Config = map[string]string{}
 	}
@@ -967,7 +974,11 @@ func (c *cmdNetworkInfo) Run(cmd *cobra.Command, args []string) error {
 
 	// Interface information.
 	fmt.Printf(i18n.G("Name: %s")+"\n", resource.name)
-	fmt.Printf(i18n.G("MAC address: %s")+"\n", state.Hwaddr)
+
+	if state.Hwaddr != "" {
+		fmt.Printf(i18n.G("MAC address: %s")+"\n", state.Hwaddr)
+	}
+
 	fmt.Printf(i18n.G("MTU: %d")+"\n", state.Mtu)
 	fmt.Printf(i18n.G("State: %s")+"\n", state.State)
 	fmt.Printf(i18n.G("Type: %s")+"\n", state.Type)
@@ -982,12 +993,14 @@ func (c *cmdNetworkInfo) Run(cmd *cobra.Command, args []string) error {
 	}
 
 	// Network usage.
-	fmt.Println("")
-	fmt.Println(i18n.G("Network usage:"))
-	fmt.Printf("  %s: %s\n", i18n.G("Bytes received"), units.GetByteSizeString(state.Counters.BytesReceived, 2))
-	fmt.Printf("  %s: %s\n", i18n.G("Bytes sent"), units.GetByteSizeString(state.Counters.BytesSent, 2))
-	fmt.Printf("  %s: %d\n", i18n.G("Packets received"), state.Counters.PacketsReceived)
-	fmt.Printf("  %s: %d\n", i18n.G("Packets sent"), state.Counters.PacketsSent)
+	if state.Counters != nil {
+		fmt.Println("")
+		fmt.Println(i18n.G("Network usage:"))
+		fmt.Printf("  %s: %s\n", i18n.G("Bytes received"), units.GetByteSizeString(state.Counters.BytesReceived, 2))
+		fmt.Printf("  %s: %s\n", i18n.G("Bytes sent"), units.GetByteSizeString(state.Counters.BytesSent, 2))
+		fmt.Printf("  %s: %d\n", i18n.G("Packets received"), state.Counters.PacketsReceived)
+		fmt.Printf("  %s: %d\n", i18n.G("Packets sent"), state.Counters.PacketsSent)
+	}
 
 	// Bond information.
 	if state.Bond != nil {
@@ -1026,10 +1039,26 @@ func (c *cmdNetworkInfo) Run(cmd *cobra.Command, args []string) error {
 	if state.OVN != nil {
 		fmt.Println("")
 		fmt.Println(i18n.G("OVN:"))
-		fmt.Printf("  %s: %s\n", i18n.G("Chassis"), state.OVN.Chassis)
-		if client.HasExtension("network_state_ovn_lr") {
+
+		if state.OVN.Chassis != "" {
+			fmt.Printf("  %s: %s\n", i18n.G("Chassis"), state.OVN.Chassis)
+		}
+
+		if state.OVN.LogicalRouter != "" {
 			fmt.Printf("  %s: %s\n", i18n.G("Logical router"), state.OVN.LogicalRouter)
 		}
+
+		if state.OVN.LogicalSwitch != "" {
+			fmt.Printf("  %s: %s\n", i18n.G("Logical switch"), state.OVN.LogicalSwitch)
+		}
+
+		if state.OVN.UplinkIPv4 != "" {
+			fmt.Printf("  %s: %s\n", i18n.G("IPv4 uplink address"), state.OVN.UplinkIPv4)
+		}
+
+		if state.OVN.UplinkIPv6 != "" {
+			fmt.Printf("  %s: %s\n", i18n.G("IPv6 uplink address"), state.OVN.UplinkIPv6)
+		}
 	}
 
 	return nil
@@ -1070,8 +1099,13 @@ t - Interface type
 u - Used by (count)`))
 
 	cmd.Flags().StringVarP(&c.flagColumns, "columns", "c", defaultNetworkColumns, i18n.G("Columns")+"``")
-	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G("Format (csv|json|table|yaml|compact)")+"``")
+	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G(`Format (csv|json|table|yaml|compact), use suffix ",noheader" to disable headers and ",header" to enable it if missing, e.g. csv,header`)+"``")
 	cmd.Flags().BoolVar(&c.flagAllProjects, "all-projects", false, i18n.G("List networks in all projects"))
+
+	cmd.PreRunE = func(cmd *cobra.Command, args []string) error {
+		return cli.ValidateFlagFormatForListOutput(cmd.Flag("format").Value.String())
+	}
+
 	cmd.RunE = c.Run
 
 	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
@@ -1269,9 +1303,13 @@ Pre-defined column shorthand chars:
   i - IP Address
   t - Type
   L - Location of the DHCP Lease (e.g. its cluster member)`))
-	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G("Format (csv|json|table|yaml|compact)")+"``")
+	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G(`Format (csv|json|table|yaml|compact), use suffix ",noheader" to disable headers and ",header" to enable it if missing, e.g. csv,header`)+"``")
 	cmd.Flags().StringVarP(&c.flagColumns, "columns", "c", defaultNetworkListLeasesColumns, i18n.G("Columns")+"``")
 
+	cmd.PreRunE = func(cmd *cobra.Command, args []string) error {
+		return cli.ValidateFlagFormatForListOutput(cmd.Flag("format").Value.String())
+	}
+
 	cmd.RunE = c.Run
 
 	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
