@@ -94,9 +94,13 @@ func (c *cmdNetworkACLList) Command() *cobra.Command {
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G("List available network ACL"))
 
 	cmd.RunE = c.Run
-	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G("Format (csv|json|table|yaml|compact)")+"``")
+	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G(`Format (csv|json|table|yaml|compact), use suffix ",noheader" to disable headers and ",header" to enable it if missing, e.g. csv,header`)+"``")
 	cmd.Flags().BoolVar(&c.flagAllProjects, "all-projects", false, i18n.G("List network ACLs across all projects"))
 
+	cmd.PreRunE = func(cmd *cobra.Command, args []string) error {
+		return cli.ValidateFlagFormatForListOutput(cmd.Flag("format").Value.String())
+	}
+
 	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		if len(args) == 0 {
 			return c.global.cmpRemotes(toComplete, false)
@@ -371,6 +375,8 @@ func (c *cmdNetworkACLGet) Run(cmd *cobra.Command, args []string) error {
 type cmdNetworkACLCreate struct {
 	global     *cmdGlobal
 	networkACL *cmdNetworkACL
+
+	flagDescription string
 }
 
 func (c *cmdNetworkACLCreate) Command() *cobra.Command {
@@ -383,6 +389,8 @@ func (c *cmdNetworkACLCreate) Command() *cobra.Command {
 incus network acl create a1 < config.yaml
     Create network acl with configuration from config.yaml`))
 
+	cmd.Flags().StringVar(&c.flagDescription, "description", "", i18n.G("Network ACL description")+"``")
+
 	cmd.RunE = c.Run
 
 	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
@@ -437,6 +445,10 @@ func (c *cmdNetworkACLCreate) Run(cmd *cobra.Command, args []string) error {
 		NetworkACLPut: aclPut,
 	}
 
+	if c.flagDescription != "" {
+		acl.Description = c.flagDescription
+	}
+
 	if acl.Config == nil {
 		acl.Config = map[string]string{}
 	}
@@ -852,6 +864,7 @@ type cmdNetworkACLRule struct {
 	global          *cmdGlobal
 	networkACL      *cmdNetworkACL
 	flagRemoveForce bool
+	flagDescription string
 }
 
 func (c *cmdNetworkACLRule) Command() *cobra.Command {
@@ -874,6 +887,9 @@ func (c *cmdNetworkACLRule) CommandAdd() *cobra.Command {
 	cmd.Use = usage("add", i18n.G("[<remote>:]<ACL> <direction> <key>=<value>..."))
 	cmd.Short = i18n.G("Add rules to an ACL")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G("Add rules to an ACL"))
+
+	cmd.Flags().StringVar(&c.flagDescription, "description", "", i18n.G("Rule description")+"``")
+
 	cmd.RunE = c.RunAdd
 
 	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
@@ -987,6 +1003,10 @@ func (c *cmdNetworkACLRule) RunAdd(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
+	if c.flagDescription != "" {
+		rule.Description = c.flagDescription
+	}
+
 	rule.Normalise() // Strip space.
 
 	// Default to enabled if not specified.
