@@ -348,6 +348,8 @@ func (c *cmdProfileCopy) Run(cmd *cobra.Command, args []string) error {
 type cmdProfileCreate struct {
 	global  *cmdGlobal
 	profile *cmdProfile
+
+	flagDescription string
 }
 
 func (c *cmdProfileCreate) Command() *cobra.Command {
@@ -364,6 +366,8 @@ incus profile create p1 < config.yaml
 
 	cmd.RunE = c.Run
 
+	cmd.Flags().StringVar(&c.flagDescription, "description", "", i18n.G("Profile description")+"``")
+
 	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		if len(args) == 0 {
 			return c.global.cmpRemotes(toComplete, false)
@@ -414,6 +418,10 @@ func (c *cmdProfileCreate) Run(cmd *cobra.Command, args []string) error {
 	profile.Name = resource.name
 	profile.ProfilePut = stdinData
 
+	if c.flagDescription != "" {
+		profile.Description = c.flagDescription
+	}
+
 	err = resource.server.CreateProfile(profile)
 	if err != nil {
 		return err
@@ -723,9 +731,13 @@ u - Used By`))
 
 	cmd.RunE = c.Run
 	cmd.Flags().StringVarP(&c.flagColumns, "columns", "c", defaultProfileColumns, i18n.G("Columns")+"``")
-	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G("Format (csv|json|table|yaml|compact)")+"``")
+	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G(`Format (csv|json|table|yaml|compact), use suffix ",noheader" to disable headers and ",header" to enable it if missing, e.g. csv,header`)+"``")
 	cmd.Flags().BoolVar(&c.flagAllProjects, "all-projects", false, i18n.G("Display profiles from all projects"))
 
+	cmd.PreRunE = func(cmd *cobra.Command, args []string) error {
+		return cli.ValidateFlagFormatForListOutput(cmd.Flag("format").Value.String())
+	}
+
 	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		if len(args) == 0 {
 			return c.global.cmpRemotes(toComplete, false)
@@ -737,8 +749,10 @@ u - Used By`))
 	return cmd
 }
 
-const defaultProfileColumns = "ndu"
-const defaultProfileColumnsAllProjects = "endu"
+const (
+	defaultProfileColumns            = "ndu"
+	defaultProfileColumnsAllProjects = "endu"
+)
 
 func (c *cmdProfileList) parseColumns() ([]profileColumn, error) {
 	columnsShorthandMap := map[rune]profileColumn{
