@@ -70,6 +70,7 @@ var api10 = []APIEndpoint{
 	instanceSnapshotsCmd,
 	instanceStateCmd,
 	instanceAccessCmd,
+	instanceDebugMemoryCmd,
 	eventsCmd,
 	imageAliasCmd,
 	imageAliasesCmd,
@@ -674,7 +675,6 @@ func doApi10Update(d *Daemon, r *http.Request, req api.ServerPut, patch bool) re
 
 			return nil
 		})
-
 		if err != nil {
 			logger.Warn("Failed reverting node config", logger.Ctx{"err": err})
 		}
@@ -735,7 +735,6 @@ func doApi10Update(d *Daemon, r *http.Request, req api.ServerPut, patch bool) re
 
 			return nil
 		})
-
 		if err != nil {
 			logger.Warn("Failed reverting cluster config", logger.Ctx{"err": err})
 		}
@@ -798,7 +797,7 @@ func doApi10UpdateTriggers(d *Daemon, nodeChanged, clusterChanged map[string]str
 
 	for key := range clusterChanged {
 		switch key {
-		case "acme.ca_url", "acme.domain":
+		case "acme.agree_tos", "acme.ca_url", "acme.challenge", "acme.domain", "acme.email", "acme.provider", "acme.provider.environment", "acme.provider.resolvers":
 			acmeChanged = true
 
 		case "cluster.images_minimal_replica":
@@ -932,7 +931,7 @@ func doApi10UpdateTriggers(d *Daemon, nodeChanged, clusterChanged map[string]str
 		asn := clusterConfig.BGPASN()
 		routerid := nodeConfig.BGPRouterID()
 
-		err := s.BGP.Reconfigure(address, uint32(asn), net.ParseIP(routerid))
+		err := s.BGP.Configure(address, uint32(asn), net.ParseIP(routerid))
 		if err != nil {
 			return fmt.Errorf("Failed reconfiguring BGP: %w", err)
 		}
