@@ -15,6 +15,7 @@ import (
 	"github.com/gorilla/mux"
 
 	incus "github.com/lxc/incus/v6/client"
+	"github.com/lxc/incus/v6/internal/filter"
 	"github.com/lxc/incus/v6/internal/jmap"
 	"github.com/lxc/incus/v6/internal/server/auth"
 	"github.com/lxc/incus/v6/internal/server/db"
@@ -73,6 +74,12 @@ var projectAccessCmd = APIEndpoint{
 //  ---
 //  produces:
 //    - application/json
+//  parameters:
+//    - in: query
+//      name: filter
+//      description: Collection filter
+//      type: string
+//      example: default
 //  responses:
 //    "200":
 //      description: API endpoints
@@ -109,59 +116,72 @@ var projectAccessCmd = APIEndpoint{
 
 // swagger:operation GET /1.0/projects?recursion=1 projects projects_get_recursion1
 //
-//	Get the projects
+//  Get the projects
 //
-//	Returns a list of projects (structs).
+//  Returns a list of projects (structs).
 //
-//	---
-//	produces:
-//	  - application/json
-//	responses:
-//	  "200":
-//	    description: API endpoints
-//	    schema:
-//	      type: object
-//	      description: Sync response
-//	      properties:
-//	        type:
-//	          type: string
-//	          description: Response type
-//	          example: sync
-//	        status:
-//	          type: string
-//	          description: Status description
-//	          example: Success
-//	        status_code:
-//	          type: integer
-//	          description: Status code
-//	          example: 200
-//	        metadata:
-//	          type: array
-//	          description: List of projects
-//	          items:
-//	            $ref: "#/definitions/Project"
-//	  "403":
-//	    $ref: "#/responses/Forbidden"
-//	  "500":
-//	    $ref: "#/responses/InternalServerError"
+//  ---
+//  produces:
+//    - application/json
+//  parameters:
+//    - in: query
+//      name: filter
+//      description: Collection filter
+//      type: string
+//      example: default
+//  responses:
+//    "200":
+//      description: API endpoints
+//      schema:
+//        type: object
+//        description: Sync response
+//        properties:
+//          type:
+//            type: string
+//            description: Response type
+//            example: sync
+//          status:
+//            type: string
+//            description: Status description
+//            example: Success
+//          status_code:
+//            type: integer
+//            description: Status code
+//            example: 200
+//          metadata:
+//            type: array
+//            description: List of projects
+//            items:
+//              $ref: "#/definitions/Project"
+//    "403":
+//      $ref: "#/responses/Forbidden"
+//    "500":
+//      $ref: "#/responses/InternalServerError"
+
 func projectsGet(d *Daemon, r *http.Request) response.Response {
 	s := d.State()
 
 	recursion := localUtil.IsRecursionRequest(r)
 
+	// Parse filter value.
+	filterStr := r.FormValue("filter")
+	clauses, err := filter.Parse(filterStr, filter.QueryOperatorSet())
+	if err != nil {
+		return response.BadRequest(fmt.Errorf("Invalid filter: %w", err))
+	}
+
 	userHasPermission, err := s.Authorizer.GetPermissionChecker(r.Context(), r, auth.EntitlementCanView, auth.ObjectTypeProject)
 	if err != nil {
 		return response.InternalError(err)
 	}
 
-	var result any
+	filtered := make([]api.Project, 0)
 	err = s.DB.Cluster.Transaction(r.Context(), func(ctx context.Context, tx *db.ClusterTx) error {
 		projects, err := cluster.GetProjects(ctx, tx.Tx())
 		if err != nil {
 			return err
 		}
 
-		filtered := []api.Project{}
 		for _, project := range projects {
 			if !userHasPermission(auth.ObjectProject(project.Name)) {
 				continue
@@ -177,18 +197,18 @@ func projectsGet(d *Daemon, r *http.Request) response.Response {
 				return err
 			}
 
-			filtered = append(filtered, *apiProject)
-		}
+			if clauses != nil && len(clauses.Clauses) > 0 {
+				match, err := filter.Match(*apiProject, *clauses)
+				if err != nil {
+					return err
+				}
 
-		if recursion {
-			result = filtered
-		} else {
-			urls := make([]string, len(filtered))
-			for i, p := range filtered {
-				urls[i] = p.URL(version.APIVersion).String()
+				if !match {
+					continue
+				}
 			}
 
-			result = urls
+			filtered = append(filtered, *apiProject)
 		}
 
 		return nil
@@ -197,7 +217,16 @@ func projectsGet(d *Daemon, r *http.Request) response.Response {
 		return response.SmartError(err)
 	}
 
-	return response.SyncResponse(true, result)
+	if recursion {
+		return response.SyncResponse(true, filtered)
+	}
+
+	urls := make([]string, len(filtered))
+	for i, p := range filtered {
+		urls[i] = p.URL(version.APIVersion).String()
+	}
+
+	return response.SyncResponse(true, urls)
 }
 
 // projectUsedBy returns a list of URLs for all instances, images, profiles,
@@ -761,7 +790,6 @@ func projectChange(ctx context.Context, s *state.State, project *api.Project, re
 
 		return nil
 	})
-
 	if err != nil {
 		return response.SmartError(err)
 	}
@@ -1550,7 +1578,7 @@ func projectValidateConfig(s *state.State, config map[string]string) error {
 		// gendoc:generate(entity=project, group=restricted, key=restricted.containers.privilege)
 		// Possible values are `unprivileged`, `isolated`, and `allow`.
 		//
-		// - When set to `unpriviliged`, this option prevents setting {config:option}`instance-security:security.privileged` to `true`.
+		// - When set to `unprivileged`, this option prevents setting {config:option}`instance-security:security.privileged` to `true`.
 		// - When set to `isolated`, this option prevents setting {config:option}`instance-security:security.privileged` and {config:option}`instance-security:security.idmap.isolated` to `true`.
 		// - When set to `allow`, there is no restriction.
 		// ---
@@ -1942,7 +1970,6 @@ func projectAccess(d *Daemon, r *http.Request) response.Response {
 
 	// get the access struct
 	access, err := s.Authorizer.GetProjectAccess(context.TODO(), name)
-
 	if err != nil {
 		return response.InternalError(err)
 	}
