@@ -292,7 +292,7 @@ func daemonStorageMove(s *state.State, storageType string, target string) error
 		}
 
 		// Re-create as a directory.
-		err = os.MkdirAll(destPath, 0700)
+		err = os.MkdirAll(destPath, 0o700)
 		if err != nil {
 			return fmt.Errorf("Failed to create directory %q: %w", destPath, err)
 		}
@@ -340,7 +340,7 @@ func daemonStorageMove(s *state.State, storageType string, target string) error
 	mountpoint := storageDrivers.GetVolumeMountPath(poolName, storageDrivers.VolumeTypeCustom, volStorageName)
 	destPath = mountpoint
 
-	err = os.Chmod(mountpoint, 0700)
+	err = os.Chmod(mountpoint, 0o700)
 	if err != nil {
 		return fmt.Errorf("Failed to set permissions on %q: %w", mountpoint, err)
 	}
