@@ -20,8 +20,10 @@ import (
 	"github.com/lxc/incus/v6/shared/ws"
 )
 
-var eventTypes = []string{api.EventTypeLogging, api.EventTypeOperation, api.EventTypeLifecycle, api.EventTypeNetworkACL}
-var privilegedEventTypes = []string{api.EventTypeLogging}
+var (
+	eventTypes           = []string{api.EventTypeLogging, api.EventTypeOperation, api.EventTypeLifecycle, api.EventTypeNetworkACL}
+	privilegedEventTypes = []string{api.EventTypeLogging}
+)
 
 var eventsCmd = APIEndpoint{
 	Path: "events",
@@ -107,16 +109,13 @@ func eventsSocket(s *state.State, r *http.Request, w http.ResponseWriter) error
 	l := logger.AddContext(logger.Ctx{"remote": r.RemoteAddr})
 
 	var excludeLocations []string
-	// Get the current local serverName and store it for the events.
-	// We do that now to avoid issues with changes to the name and to limit
-	// the number of DB access to just one per connection.
-	err := s.DB.Cluster.Transaction(context.TODO(), func(ctx context.Context, tx *db.ClusterTx) error {
-		if isClusterNotification(r) {
-			ctx := r.Context()
+	if isClusterNotification(r) {
+		ctx := r.Context()
 
-			// Try and match cluster member certificate fingerprint to member name.
-			fingerprint, found := ctx.Value(request.CtxUsername).(string)
-			if found {
+		// Try and match cluster member certificate fingerprint to member name.
+		fingerprint, found := ctx.Value(request.CtxUsername).(string)
+		if found {
+			err := s.DB.Cluster.Transaction(context.TODO(), func(ctx context.Context, tx *db.ClusterTx) error {
 				cert, err := cluster.GetCertificateByFingerprintPrefix(context.Background(), tx.Tx(), fingerprint)
 				if err != nil {
 					return fmt.Errorf("Failed matching client certificate to cluster member: %w", err)
@@ -125,14 +124,14 @@ func eventsSocket(s *state.State, r *http.Request, w http.ResponseWriter) error
 				// Add the cluster member client's name to the excluded locations so that we can avoid
 				// looping the event back to them when they send us an event via recvFunc.
 				excludeLocations = append(excludeLocations, cert.Name)
+
+				return nil
+			})
+			if err != nil {
+				l.Warn("Failed setting up event connection", logger.Ctx{"err": err})
+				return nil
 			}
 		}
-
-		return nil
-	})
-	if err != nil {
-		l.Warn("Failed setting up event connection", logger.Ctx{"err": err})
-		return nil
 	}
 
 	var recvFunc events.EventHandler
