@@ -137,12 +137,12 @@ func instancePut(d *Daemon, r *http.Request) response.Response {
 				return err
 			}
 
-			profileConfigs, err := cluster.GetConfig(ctx, tx.Tx(), "profile")
+			profileConfigs, err := cluster.GetAllProfileConfigs(ctx, tx.Tx())
 			if err != nil {
 				return err
 			}
 
-			profileDevices, err := cluster.GetDevices(ctx, tx.Tx(), "profile")
+			profileDevices, err := cluster.GetAllProfileDevices(ctx, tx.Tx())
 			if err != nil {
 				return err
 			}
