@@ -165,6 +165,13 @@ var instanceAccessCmd = APIEndpoint{
 	Get: APIEndpointAction{Handler: instanceAccess, AccessHandler: allowPermission(auth.ObjectTypeInstance, auth.EntitlementCanView, "name")},
 }
 
+var instanceDebugMemoryCmd = APIEndpoint{
+	Name: "instanceDebugMemory",
+	Path: "instances/{name}/debug/memory",
+
+	Get: APIEndpointAction{Handler: instanceDebugMemoryGet, AccessHandler: allowPermission(auth.ObjectTypeInstance, auth.EntitlementCanEdit, "name")},
+}
+
 type instanceAutostartList []instance.Instance
 
 func (slice instanceAutostartList) Len() int {
@@ -202,7 +209,7 @@ func instanceShouldAutoStart(inst instance.Instance) bool {
 
 func instancesStart(s *state.State, instances []instance.Instance) {
 	// Check if the cluster is currently evacuated.
-	if s.DB.Cluster.LocalNodeIsEvacuated() {
+	if s.ServerClustered && s.DB.Cluster.LocalNodeIsEvacuated() {
 		return
 	}
 
@@ -235,7 +242,7 @@ func instancesStart(s *state.State, instances []instance.Instance) {
 		instLogger := logger.AddContext(logger.Ctx{"project": inst.Project().Name, "instance": inst.Name()})
 
 		// Try to start the instance.
-		var attempt = 0
+		attempt := 0
 		for {
 			attempt++
 
