@@ -11,6 +11,7 @@ import (
 
 	"github.com/gorilla/mux"
 
+	"github.com/lxc/incus/v6/internal/filter"
 	"github.com/lxc/incus/v6/internal/server/auth"
 	clusterRequest "github.com/lxc/incus/v6/internal/server/cluster/request"
 	"github.com/lxc/incus/v6/internal/server/db"
@@ -71,6 +72,11 @@ var networkACLLogCmd = APIEndpoint{
 //      description: Retrieve network ACLs from all projects
 //      type: boolean
 //      example: true
+//    - in: query
+//      name: filter
+//      description: Collection filter
+//      type: string
+//      example: default
 //  responses:
 //    "200":
 //      description: API endpoints
@@ -107,52 +113,58 @@ var networkACLLogCmd = APIEndpoint{
 
 // swagger:operation GET /1.0/network-acls?recursion=1 network-acls network_acls_get_recursion1
 //
-//	Get the network ACLs
+//  Get the network ACLs
 //
-//	Returns a list of network ACLs (structs).
+//  Returns a list of network ACLs (structs).
 //
-//	---
-//	produces:
-//	  - application/json
-//	parameters:
-//	  - in: query
-//	    name: project
-//	    description: Project name
-//	    type: string
-//	    example: default
-//	  - in: query
-//	    name: all-projects
-//	    description: Retrieve network ACLs from all projects
-//	    type: boolean
-//	    example: true
-//	responses:
-//	  "200":
-//	    description: API endpoints
-//	    schema:
-//	      type: object
-//	      description: Sync response
-//	      properties:
-//	        type:
-//	          type: string
-//	          description: Response type
-//	          example: sync
-//	        status:
-//	          type: string
-//	          description: Status description
-//	          example: Success
-//	        status_code:
-//	          type: integer
-//	          description: Status code
-//	          example: 200
-//	        metadata:
-//	          type: array
-//	          description: List of network ACLs
-//	          items:
-//	            $ref: "#/definitions/NetworkACL"
-//	  "403":
-//	    $ref: "#/responses/Forbidden"
-//	  "500":
-//	    $ref: "#/responses/InternalServerError"
+//  ---
+//  produces:
+//    - application/json
+//  parameters:
+//    - in: query
+//      name: project
+//      description: Project name
+//      type: string
+//      example: default
+//    - in: query
+//      name: all-projects
+//      description: Retrieve network ACLs from all projects
+//      type: boolean
+//      example: true
+//    - in: query
+//      name: filter
+//      description: Collection filter
+//      type: string
+//      example: default
+//  responses:
+//    "200":
+//      description: API endpoints
+//      schema:
+//        type: object
+//        description: Sync response
+//        properties:
+//          type:
+//            type: string
+//            description: Response type
+//            example: sync
+//          status:
+//            type: string
+//            description: Status description
+//            example: Success
+//          status_code:
+//            type: integer
+//            description: Status code
+//            example: 200
+//          metadata:
+//            type: array
+//            description: List of network ACLs
+//            items:
+//              $ref: "#/definitions/NetworkACL"
+//    "403":
+//      $ref: "#/responses/Forbidden"
+//    "500":
+//      $ref: "#/responses/InternalServerError"
+
 func networkACLsGet(d *Daemon, r *http.Request) response.Response {
 	s := d.State()
 
@@ -164,6 +176,15 @@ func networkACLsGet(d *Daemon, r *http.Request) response.Response {
 	recursion := localUtil.IsRecursionRequest(r)
 	allProjects := util.IsTrue(r.FormValue("all-projects"))
 
+	// Parse filter value.
+	filterStr := r.FormValue("filter")
+	clauses, err := filter.Parse(filterStr, filter.QueryOperatorSet())
+	if err != nil {
+		return response.BadRequest(fmt.Errorf("Invalid filter: %w", err))
+	}
+
+	mustLoadObjects := recursion || (clauses != nil && len(clauses.Clauses) > 0)
+
 	var aclNames map[string][]string
 
 	err = s.DB.Cluster.Transaction(r.Context(), func(ctx context.Context, tx *db.ClusterTx) error {
@@ -197,17 +218,15 @@ func networkACLsGet(d *Daemon, r *http.Request) response.Response {
 		return response.SmartError(err)
 	}
 
-	resultString := []string{}
-	resultMap := []api.NetworkACL{}
+	linkResults := make([]string, 0)
+	fullResults := make([]api.NetworkACL, 0)
 	for projectName, acls := range aclNames {
 		for _, aclName := range acls {
 			if !userHasPermission(auth.ObjectNetworkACL(projectName, aclName)) {
 				continue
 			}
 
-			if !recursion {
-				resultString = append(resultString, fmt.Sprintf("/%s/network-acls/%s", version.APIVersion, aclName))
-			} else {
+			if mustLoadObjects {
 				netACL, err := acl.LoadByName(s, projectName, aclName)
 				if err != nil {
 					continue
@@ -216,16 +235,29 @@ func networkACLsGet(d *Daemon, r *http.Request) response.Response {
 				netACLInfo := netACL.Info()
 				netACLInfo.UsedBy, _ = netACL.UsedBy() // Ignore errors in UsedBy, will return nil.
 
-				resultMap = append(resultMap, *netACLInfo)
+				if clauses != nil && len(clauses.Clauses) > 0 {
+					match, err := filter.Match(*netACLInfo, *clauses)
+					if err != nil {
+						return response.SmartError(err)
+					}
+
+					if !match {
+						continue
+					}
+				}
+
+				fullResults = append(fullResults, *netACLInfo)
 			}
+
+			linkResults = append(linkResults, fmt.Sprintf("/%s/network-acls/%s", version.APIVersion, aclName))
 		}
 	}
 
 	if !recursion {
-		return response.SyncResponse(true, resultString)
+		return response.SyncResponse(true, linkResults)
 	}
 
-	return response.SyncResponse(true, resultMap)
+	return response.SyncResponse(true, fullResults)
 }
 
 // swagger:operation POST /1.0/network-acls network-acls network_acls_post
