@@ -10,6 +10,7 @@ import (
 
 	"github.com/gorilla/mux"
 
+	"github.com/lxc/incus/v6/internal/filter"
 	"github.com/lxc/incus/v6/internal/server/auth"
 	"github.com/lxc/incus/v6/internal/server/db"
 	dbCluster "github.com/lxc/incus/v6/internal/server/db/cluster"
@@ -52,6 +53,12 @@ var networkIntegrationCmd = APIEndpoint{
 //  ---
 //  produces:
 //    - application/json
+//  parameters:
+//    - in: query
+//      name: filter
+//      description: Collection filter
+//      type: string
+//      example: default
 //  responses:
 //    "200":
 //      description: API endpoints
@@ -88,54 +95,70 @@ var networkIntegrationCmd = APIEndpoint{
 
 // swagger:operation GET /1.0/network-integrations?recursion=1 network-integrations network_integrations_get_recursion1
 //
-//	Get the network integrations
+//  Get the network integrations
 //
-//	Returns a list of network integrations (structs).
+//  Returns a list of network integrations (structs).
 //
-//	---
-//	produces:
-//	  - application/json
-//	responses:
-//	  "200":
-//	    description: API endpoints
-//	    schema:
-//	      type: object
-//	      description: Sync response
-//	      properties:
-//	        type:
-//	          type: string
-//	          description: Response type
-//	          example: sync
-//	        status:
-//	          type: string
-//	          description: Status description
-//	          example: Success
-//	        status_code:
-//	          type: integer
-//	          description: Status code
-//	          example: 200
-//	        metadata:
-//	          type: array
-//	          description: List of network integrations
-//	          items:
-//	            $ref: "#/definitions/NetworkIntegration"
-//	  "403":
-//	    $ref: "#/responses/Forbidden"
-//	  "500":
-//	    $ref: "#/responses/InternalServerError"
+//  ---
+//  produces:
+//    - application/json
+//  parameters:
+//     - in: query
+//       name: filter
+//       description: Collection filter
+//       type: string
+//       example: default
+//  responses:
+//    "200":
+//      description: API endpoints
+//      schema:
+//        type: object
+//        description: Sync response
+//        properties:
+//          type:
+//            type: string
+//            description: Response type
+//            example: sync
+//          status:
+//            type: string
+//            description: Status description
+//            example: Success
+//          status_code:
+//            type: integer
+//            description: Status code
+//            example: 200
+//          metadata:
+//            type: array
+//            description: List of network integrations
+//            items:
+//              $ref: "#/definitions/NetworkIntegration"
+//    "403":
+//      $ref: "#/responses/Forbidden"
+//    "500":
+//      $ref: "#/responses/InternalServerError"
+
 func networkIntegrationsGet(d *Daemon, r *http.Request) response.Response {
 	s := d.State()
 
 	recursion := localUtil.IsRecursionRequest(r)
 
+	// Parse filter value.
+	filterStr := r.FormValue("filter")
+	clauses, err := filter.Parse(filterStr, filter.QueryOperatorSet())
+	if err != nil {
+		return response.BadRequest(fmt.Errorf("Invalid filter: %w", err))
+	}
+
+	mustLoadObjects := recursion || (clauses != nil && len(clauses.Clauses) > 0)
+
 	// Network integrations aren't project aware, we only load the per-project data to apply name restrictions.
 	projectName := request.ProjectParam(r)
 
 	// Get list of Network integrations.
-	resultString := []string{}
-	resultMap := []api.NetworkIntegration{}
+	linkResults := make([]string, 0)
+	fullResults := make([]api.NetworkIntegration, 0)
 
-	err := s.DB.Cluster.Transaction(r.Context(), func(ctx context.Context, tx *db.ClusterTx) error {
+	err = s.DB.Cluster.Transaction(r.Context(), func(ctx context.Context, tx *db.ClusterTx) error {
 		var err error
 
 		// Load the project.
@@ -161,9 +184,7 @@ func networkIntegrationsGet(d *Daemon, r *http.Request) response.Response {
 				continue
 			}
 
-			if !recursion {
-				resultString = append(resultString, api.NewURL().Path(version.APIVersion, "network-integrations", integration.Name).String())
-			} else {
+			if mustLoadObjects {
 				// Get the integration.
 				result, err := integration.ToAPI(r.Context(), tx.Tx())
 				if err != nil {
@@ -184,8 +205,21 @@ func networkIntegrationsGet(d *Daemon, r *http.Request) response.Response {
 
 				result.UsedBy = usedBy
 
-				resultMap = append(resultMap, *result)
+				if clauses != nil && len(clauses.Clauses) > 0 {
+					match, err := filter.Match(*result, *clauses)
+					if err != nil {
+						return err
+					}
+
+					if !match {
+						continue
+					}
+				}
+
+				fullResults = append(fullResults, *result)
 			}
+
+			linkResults = append(linkResults, api.NewURL().Path(version.APIVersion, "network-integrations", integration.Name).String())
 		}
 
 		return nil
@@ -195,10 +229,10 @@ func networkIntegrationsGet(d *Daemon, r *http.Request) response.Response {
 	}
 
 	if !recursion {
-		return response.SyncResponse(true, resultString)
+		return response.SyncResponse(true, linkResults)
 	}
 
-	return response.SyncResponse(true, resultMap)
+	return response.SyncResponse(true, fullResults)
 }
 
 // swagger:operation POST /1.0/network-integrations network-integrations network_integrations_post
