@@ -5,7 +5,7 @@ import (
 	"net/http"
 	"time"
 
-	"github.com/lxc/incus/v6/client"
+	incus "github.com/lxc/incus/v6/client"
 	"github.com/lxc/incus/v6/shared/util"
 )
 
