@@ -11,8 +11,10 @@ import (
 	"github.com/lxc/incus/v6/shared/util"
 )
 
-var minLXDVersion = &version.DottedVersion{Major: 4, Minor: 0, Patch: 0}
-var maxLXDVersion = &version.DottedVersion{Major: 5, Minor: 21, Patch: 99}
+var (
+	minLXDVersion = &version.DottedVersion{Major: 4, Minor: 0, Patch: 0}
+	maxLXDVersion = &version.DottedVersion{Major: 5, Minor: 21, Patch: 99}
+)
 
 func (c *cmdMigrate) validate(source source, target target) error {
 	srcClient, err := source.connect()
@@ -81,7 +83,7 @@ func (c *cmdMigrate) validate(source source, target target) error {
 			return false, nil
 		}
 
-		// Check if any instance is persent.
+		// Check if any instance is present.
 		names, err = srcClient.GetInstanceNames(api.InstanceTypeAny)
 		if err != nil {
 			return false, err
