@@ -6,8 +6,8 @@ import (
 
 	"github.com/stretchr/testify/assert"
 
-	"github.com/lxc/incus/internal/filter"
-	"github.com/lxc/incus/shared/api"
+	"github.com/lxc/incus/v6/internal/filter"
+	"github.com/lxc/incus/v6/shared/api"
 )
 
 func TestValueOf_Instance(t *testing.T) {
