@@ -23,9 +23,11 @@ const (
 	cmdParse  = "Q"
 )
 
-var aaCacheDir string
-var aaPath = internalUtil.VarPath("security", "apparmor")
-var aaVersion *version.DottedVersion
+var (
+	aaCacheDir string
+	aaPath     = internalUtil.VarPath("security", "apparmor")
+	aaVersion  *version.DottedVersion
+)
 
 // Init performs initial version and feature detection.
 func Init() error {
@@ -77,7 +79,6 @@ func runApparmor(sysOS *sys.OS, command string, name string) error {
 		filepath.Join(aaPath, "cache"),
 		filepath.Join(aaPath, "profiles", name),
 	}...)
-
 	if err != nil {
 		return err
 	}
@@ -96,7 +97,7 @@ func createNamespace(sysOS *sys.OS, name string) error {
 	}
 
 	p := filepath.Join("/sys/kernel/security/apparmor/policy/namespaces", name)
-	err := os.Mkdir(p, 0755)
+	err := os.Mkdir(p, 0o755)
 	if err != nil && !os.IsExist(err) {
 		return err
 	}
@@ -125,7 +126,7 @@ func deleteNamespace(sysOS *sys.OS, name string) error {
 
 // hasProfile checks if the profile is already loaded.
 func hasProfile(sysOS *sys.OS, name string) (bool, error) {
-	mangled := strings.Replace(strings.Replace(strings.Replace(name, "/", ".", -1), "<", "", -1), ">", "", -1)
+	mangled := strings.ReplaceAll(strings.ReplaceAll(strings.ReplaceAll(name, "/", "."), "<", ""), ">", "")
 
 	profilesPath := "/sys/kernel/security/apparmor/policy/profiles"
 	if util.PathExists(profilesPath) {
