@@ -6,7 +6,6 @@ import (
 	"os/exec"
 	"path/filepath"
 	"strings"
-	"text/template"
 
 	"github.com/google/uuid"
 
@@ -15,33 +14,6 @@ import (
 	"github.com/lxc/incus/v6/shared/revert"
 )
 
-var archiveProfileTpl = template.Must(template.New("archiveProfile").Parse(`#include <tunables/global>
-profile "{{.name}}" {
-  #include <abstractions/base>
-  #include <abstractions/nameservice>
-
-{{range $index, $element := .allowedCommandPaths}}
-  {{$element}} mixr,
-{{- end }}
-
-  {{ .outputPath }}/ rw,
-  {{ .outputPath }}/** rwl,
-  {{ .backupsPath }}/** rw,
-  {{ .imagesPath }}/** r,
-
-  signal (receive) set=("term"),
-
-  # Capabilities
-  capability chown,
-  capability dac_override,
-  capability dac_read_search,
-  capability fowner,
-  capability fsetid,
-  capability mknod,
-  capability setfcap,
-}
-`))
-
 // ArchiveWrapper is used as a RunWrapper in the rsync package.
 func ArchiveWrapper(sysOS *sys.OS, cmd *exec.Cmd, output string, allowedCmds []string) (func(), error) {
 	if !sysOS.AppArmorAvailable {
@@ -96,7 +68,7 @@ func archiveProfileLoad(sysOS *sys.OS, output string, allowedCommandPaths []stri
 	}
 
 	// Write it to disk.
-	err = os.WriteFile(profilePath, []byte(content), 0600)
+	err = os.WriteFile(profilePath, []byte(content), 0o600)
 	if err != nil {
 		return "", err
 	}
