@@ -168,7 +168,7 @@ func NewObject(objectType ObjectType, projectName string, identifierElements ...
 // Mux vars must be provided in the order that they are found in the endpoint path. If the object
 // requires a project name, this is taken from the project query parameter unless the URL begins
 // with /1.0/projects.
-func ObjectFromRequest(r *http.Request, objectType ObjectType, expandProject func(string) string, expandFingerprint func(string, string) string, muxVars ...string) (Object, error) {
+func ObjectFromRequest(r *http.Request, objectType ObjectType, expandProject func(string) string, expandFingerprint func(string, string) string, expandVolumeLocation func(string, string, string, string) string, muxVars ...string) (Object, error) {
 	// Shortcut for server objects which don't require any arguments.
 	if objectType == ObjectTypeServer {
 		return ObjectServer(), nil
@@ -196,11 +196,15 @@ func ObjectFromRequest(r *http.Request, objectType ObjectType, expandProject fun
 
 		if muxVar == "location" {
 			// Special handling for the location which is not present as a real mux var.
-			if location == "" {
-				continue
+			if location != "" {
+				muxValue = location
+			} else if objectType == ObjectTypeStorageVolume {
+				muxValue = expandVolumeLocation(projectName, vars["poolName"], vars["type"], vars["volumeName"])
 			}
 
-			muxValue = location
+			if muxValue == "" {
+				continue
+			}
 		} else {
 			muxValue, err = url.PathUnescape(vars[muxVar])
 			if err != nil {
@@ -305,7 +309,7 @@ func ObjectNetworkACL(projectName string, networkACLName string) Object {
 
 // ObjectNetworkIntegration represents a network integration.
 func ObjectNetworkIntegration(networkIntegrationName string) Object {
-	object, _ := NewObject(ObjectTypeNetworkIntegration, networkIntegrationName)
+	object, _ := NewObject(ObjectTypeNetworkIntegration, "", networkIntegrationName)
 	return object
 }
 
@@ -347,10 +351,10 @@ func ObjectStorageVolume(projectName string, poolName string, volumeType string,
 
 // escape escapes only the forward slash character as this is used as a delimiter. Everything else is allowed.
 func escape(s string) string {
-	return strings.Replace(s, "/", "%2F", -1)
+	return strings.ReplaceAll(s, "/", "%2F")
 }
 
 // unescape replaces only the escaped forward slashes.
 func unescape(s string) string {
-	return strings.Replace(s, "%2F", "/", -1)
+	return strings.ReplaceAll(s, "%2F", "/")
 }
