@@ -230,8 +230,46 @@ func (c *Config) LokiServer() (string, string, string, string, string, string, [
 }
 
 // ACME returns all ACME settings needed for certificate renewal.
-func (c *Config) ACME() (string, string, string, bool) {
-	return c.m.GetString("acme.domain"), c.m.GetString("acme.email"), c.m.GetString("acme.ca_url"), c.m.GetBool("acme.agree_tos")
+func (c *Config) ACME() (string, string, string, bool, string) {
+	return c.m.GetString("acme.domain"), c.m.GetString("acme.email"), c.m.GetString("acme.ca_url"), c.m.GetBool("acme.agree_tos"), c.m.GetString("acme.challenge")
+}
+
+// ACMEDNS returns all ACME DNS settings needed for DNS-01 challenge.
+func (c *Config) ACMEDNS() (string, []string, []string) {
+	var environment []string
+	var resolvers []string
+
+	if c.m.GetString("acme.provider.environment") != "" {
+		lines := strings.Split(strings.TrimSpace(c.m.GetString("acme.provider.environment")), "\n")
+
+		for _, line := range lines {
+			if len(strings.TrimSpace(line)) == 0 {
+				continue
+			}
+
+			parts := strings.SplitN(line, "=", 2)
+			if len(parts) != 2 {
+				logrus.Warnf("Malformed line in config string: %q", line)
+				continue
+			}
+
+			key := strings.TrimSpace(parts[0])
+			value := strings.TrimSpace(parts[1])
+
+			environment = append(environment, strings.Join([]string{key, value}, "="))
+		}
+	}
+
+	if c.m.GetString("acme.provider.resolvers") != "" {
+		resolvers = strings.Split(c.m.GetString("acme.provider.resolvers"), ",")
+	}
+
+	return c.m.GetString("acme.provider"), environment, resolvers
+}
+
+// ACMEHTTP returns all ACME HTTP settings needed for HTTP-01 challenge.
+func (c *Config) ACMEHTTP() string {
+	return c.m.GetString("acme.http.port")
 }
 
 // ClusterJoinTokenExpiry returns the cluster join token expiry.
@@ -322,7 +360,7 @@ var ConfigSchema = config.Schema{
 	//  scope: global
 	//  defaultdesc: `https://acme-v02.api.letsencrypt.org/directory`
 	//  shortdesc: URL to the directory resource of the ACME service
-	"acme.ca_url": {},
+	"acme.ca_url": {Default: "https://acme-v02.api.letsencrypt.org/directory"},
 
 	// gendoc:generate(entity=server, group=acme, key=acme.domain)
 	//
@@ -349,6 +387,51 @@ var ConfigSchema = config.Schema{
 	//  shortdesc: Agree to ACME terms of service
 	"acme.agree_tos": {Type: config.Bool, Default: "false"},
 
+	// gendoc:generate(entity=server, group=acme, key=acme.challenge)
+	// Possible values are `DNS-01` and `HTTP-01`.
+	// ---
+	//  type: string
+	//  scope: global
+	//  defaultdesc: `HTTP-01`
+	//  shortdesc: ACME challenge type to use
+	"acme.challenge": {Type: config.String, Default: "HTTP-01", Validator: validate.Optional(validate.IsOneOf("DNS-01", "HTTP-01"))},
+
+	// gendoc:generate(entity=server, group=acme, key=acme.provider)
+	//
+	// ---
+	//  type: string
+	//  scope: global
+	//  defaultdesc: ``
+	//  shortdesc: Backend provider for the challenge (used by DNS-01)
+	"acme.provider": {Type: config.String, Default: ""},
+
+	// gendoc:generate(entity=server, group=acme, key=acme.provider.environment)
+	//
+	// ---
+	//  type: string
+	//  scope: global
+	//  defaultdesc: ``
+	//  shortdesc: Environment variables to set during the challenge (used by DNS-01)
+	"acme.provider.environment": {Type: config.String, Default: ""},
+
+	// gendoc:generate(entity=server, group=acme, key=acme.provider.resolvers)
+	// DNS resolvers to use for performing (recursive) `CNAME` resolving and apex domain determination during DNS-01 challenge.
+	// ---
+	//  type: string
+	//  scope: global
+	//  defaultdesc: ``
+	//  shortdesc: Comma-separated list of DNS resolvers (used by DNS-01)
+	"acme.provider.resolvers": {Type: config.String, Default: ""},
+
+	// gendoc:generate(entity=server, group=acme, key=acme.http.port)
+	// Set the port and interface to use for HTTP-01 based challenges to listen on
+	// ---
+	//  type: string
+	//  scope: global
+	//  defaultdesc: `:80`
+	//  shortdesc: Port and interface for HTTP server (used by HTTP-01)
+	"acme.http.port": {Default: ":80", Validator: validate.Optional(validate.IsListenAddress(true, true, false))},
+
 	// gendoc:generate(entity=server, group=miscellaneous, key=authorization.scriptlet)
 	// When using scriptlet-based authorization, this option stores the scriptlet.
 	// ---
