@@ -14,25 +14,25 @@ import (
 
 // Code generation directives.
 //
-//go:generate -command mapper incus-generate db mapper -t projects.mapper.go
-//go:generate mapper reset -i -b "//go:build linux && cgo && !agent"
+//generate-database:mapper target projects.mapper.go
+//generate-database:mapper reset -i -b "//go:build linux && cgo && !agent"
 //
-//go:generate mapper stmt -e project objects
-//go:generate mapper stmt -e project objects-by-Name
-//go:generate mapper stmt -e project objects-by-ID
-//go:generate mapper stmt -e project create struct=Project
-//go:generate mapper stmt -e project id
-//go:generate mapper stmt -e project rename
-//go:generate mapper stmt -e project update struct=Project
-//go:generate mapper stmt -e project delete-by-Name
+//generate-database:mapper stmt -e project objects
+//generate-database:mapper stmt -e project objects-by-Name
+//generate-database:mapper stmt -e project objects-by-ID
+//generate-database:mapper stmt -e project create struct=Project
+//generate-database:mapper stmt -e project id
+//generate-database:mapper stmt -e project rename
+//generate-database:mapper stmt -e project update struct=Project
+//generate-database:mapper stmt -e project delete-by-Name
 //
-//go:generate mapper method -i -e project GetMany references=Config
-//go:generate mapper method -i -e project GetOne struct=Project
-//go:generate mapper method -i -e project Exists struct=Project
-//go:generate mapper method -i -e project Create references=Config
-//go:generate mapper method -i -e project ID struct=Project
-//go:generate mapper method -i -e project Rename
-//go:generate mapper method -i -e project DeleteOne-by-Name
+//generate-database:mapper method -i -e project GetMany references=Config
+//generate-database:mapper method -i -e project GetOne struct=Project
+//generate-database:mapper method -i -e project Exists struct=Project
+//generate-database:mapper method -i -e project Create references=Config
+//generate-database:mapper method -i -e project ID struct=Project
+//generate-database:mapper method -i -e project Rename
+//generate-database:mapper method -i -e project DeleteOne-by-Name
 
 // ProjectFeature indicates the behaviour of a project feature.
 type ProjectFeature struct {
@@ -214,7 +214,7 @@ DELETE FROM projects_config WHERE projects_config.project_id = ?
 		return fmt.Errorf("Delete project config: %w", err)
 	}
 
-	err = UpdateConfig(ctx, tx, "project", int(id), object.Config)
+	err = UpdateConfig(ctx, tx, "projects", "project", int(id), object.Config)
 	if err != nil {
 		return fmt.Errorf("Insert config for project: %w", err)
 	}
