@@ -9,7 +9,7 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	"github.com/lxc/incus/internal/server/db"
+	"github.com/lxc/incus/v6/internal/server/db"
 )
 
 // Node-local configuration values are initially empty.
