@@ -263,7 +263,7 @@ func OpenCluster(closingCtx context.Context, name string, store driver.NodeStore
 var ErrSomeNodesAreBehind = fmt.Errorf("some nodes are behind this node's version")
 
 // ForLocalInspection is a aid for the hack in initializeDbObject, which
-// sets the db-related Deamon attributes upfront, to be backward compatible
+// sets the db-related Daemon attributes upfront, to be backward compatible
 // with the legacy patches that need to interact with the database.
 func ForLocalInspection(db *sql.DB) *Cluster {
 	return &Cluster{
@@ -349,7 +349,7 @@ func (c *Cluster) transaction(ctx context.Context, f func(context.Context, *Clus
 			// If the query timed out it likely means that the leader has abruptly become unreachable.
 			// Now that this query has been cancelled, a leader election should have taken place by now.
 			// So let's retry the transaction once more in case the global database is now available again.
-			logger.Warn("Transaction timed out. Retrying once", logger.Ctx{"member": c.nodeID, "err": err})
+			logger.Debug("Transaction timed out, will be retried", logger.Ctx{"member": c.nodeID, "err": err})
 			return query.Transaction(ctx, c.db, txFunc)
 		}
 
