@@ -9,7 +9,7 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	"github.com/lxc/incus/internal/server/db/query"
+	"github.com/lxc/incus/v6/internal/server/db/query"
 )
 
 // Any error happening when beginning the transaction will be propagated.
