@@ -73,11 +73,11 @@ CREATE TABLE schema (
 }
 
 // Insert a new version into the schema table.
-func insertSchemaVersion(tx *sql.Tx, new int) error {
+func insertSchemaVersion(tx *sql.Tx, newVersion int) error {
 	statement := `
 INSERT INTO schema (version, updated_at) VALUES (?, strftime("%s"))
 `
-	_, err := tx.Exec(statement, new)
+	_, err := tx.Exec(statement, newVersion)
 	return err
 }
 
