@@ -322,7 +322,7 @@ func (d *disk) validateConfig(instConf instance.ConfigReader) error {
 		// ---
 		//  type: string
 		//  required: yes
-		//  shortdesc: Path inside the instance where the disk will be mounted (only for containers)
+		//  shortdesc: Path inside the instance where the disk will be mounted (only for file system disk devices)
 		"path": validate.IsAny,
 
 		// gendoc:generate(entity=devices, group=disk, key=io.cache)
@@ -351,6 +351,7 @@ func (d *disk) validateConfig(instConf instance.ConfigReader) error {
 		// - `nvme`
 		// - `virtio-blk`
 		// - `virtio-scsi` (default)
+		// - `usb`
 		//
 		// For file systems (shared directories or custom volumes), this is one of:
 		// - `9p`
@@ -361,7 +362,7 @@ func (d *disk) validateConfig(instConf instance.ConfigReader) error {
 		//  default: `virtio-scsi` for block, `auto` for file system
 		//  required: no
 		//  shortdesc: Only for VMs: Override the bus for the device
-		"io.bus": validate.Optional(validate.IsOneOf("nvme", "virtio-blk", "virtio-scsi", "auto", "9p", "virtiofs")),
+		"io.bus": validate.Optional(validate.IsOneOf("nvme", "virtio-blk", "virtio-scsi", "auto", "9p", "virtiofs", "usb")),
 	}
 
 	err := d.config.Validate(rules)
@@ -540,9 +541,10 @@ func (d *disk) validateConfig(instConf instance.ConfigReader) error {
 					}
 				}
 
+				// Parse the volume name and path.
+				volFields := strings.SplitN(d.config["source"], "/", 2)
+
 				if dbVolume == nil {
-					// Parse the volume name and path.
-					volFields := strings.SplitN(d.config["source"], "/", 2)
 					volName := volFields[0]
 
 					// GetStoragePoolVolume returns a volume with an empty Location field for remote drivers.
@@ -579,6 +581,11 @@ func (d *disk) validateConfig(instConf instance.ConfigReader) error {
 					if d.config["path"] != "" {
 						return fmt.Errorf("Custom block volumes cannot have a path defined")
 					}
+
+					if len(volFields) > 1 {
+						return fmt.Errorf("Custom block volume snapshots cannot be used directly")
+					}
+
 				} else if contentType == db.StoragePoolVolumeContentTypeISO {
 					if instConf.Type() == instancetype.Container {
 						return fmt.Errorf("Custom ISO volumes cannot be used on containers")
@@ -978,13 +985,6 @@ func (d *disk) startContainer() (*deviceConfig.RunConfig, error) {
 	return &runConf, nil
 }
 
-// vmVirtfsProxyHelperPaths returns the path for PID file to use with virtfs-proxy-helper process.
-func (d *disk) vmVirtfsProxyHelperPaths() string {
-	pidPath := filepath.Join(d.inst.DevicesPath(), fmt.Sprintf("%s.pid", d.name))
-
-	return pidPath
-}
-
 // vmVirtiofsdPaths returns the path for the socket and PID file to use with virtiofsd process.
 func (d *disk) vmVirtiofsdPaths() (string, string) {
 	sockPath := filepath.Join(d.inst.DevicesPath(), fmt.Sprintf("virtio-fs.%s.sock", d.name))
@@ -1273,22 +1273,13 @@ func (d *disk) startVM() (*deviceConfig.RunConfig, error) {
 					return nil, fmt.Errorf(`Failed parsing instance "raw.idmap": %w`, err)
 				}
 
-				// If we are using restricted parent source path mode, or if a non-empty set of
-				// raw ID maps have been supplied, then we will be running the disk proxy processes
-				// inside a user namespace as the root userns user. Therefore we need to ensure
-				// that there is a root UID and GID mapping in the raw ID maps, and if not then add
-				// one mapping the root userns user to the nouser/nogroup host ID.
-				if d.restrictedParentSourcePath != "" || len(rawIDMaps.Entries) > 0 {
-					rawIDMaps.Entries = diskAddRootUserNSEntry(rawIDMaps.Entries, 65534)
-				}
-
 				busOption := d.config["io.bus"]
 				if busOption == "" {
 					busOption = "auto"
 				}
 
 				// Start virtiofsd for virtio-fs share. The agent prefers to use this over the
-				// virtfs-proxy-helper 9p share. The 9p share will only be used as a fallback.
+				// 9p share. The 9p share will only be used as a fallback.
 				err = func() error {
 					// Check if we should start virtiofsd.
 					if busOption != "auto" && busOption != "virtiofs" {
@@ -1308,6 +1299,8 @@ func (d *disk) startVM() (*deviceConfig.RunConfig, error) {
 						var errUnsupported UnsupportedError
 						if errors.As(err, &errUnsupported) {
 							d.logger.Warn("Unable to use virtio-fs for device, using 9p as a fallback", logger.Ctx{"err": errUnsupported})
+							// Fallback to 9p-only.
+							busOption = "9p"
 
 							if errUnsupported == ErrMissingVirtiofsd {
 								_ = d.state.DB.Cluster.Transaction(context.TODO(), func(ctx context.Context, tx *db.ClusterTx) error {
@@ -1347,38 +1340,18 @@ func (d *disk) startVM() (*deviceConfig.RunConfig, error) {
 					return nil, fmt.Errorf("Failed to setup virtiofsd for device %q: %w", d.name, err)
 				}
 
-				// We can't hotplug 9p shares, so only do 9p for stopped instances.
-				if !d.inst.IsRunning() {
-					// Start virtfs-proxy-helper for 9p share (this will rewrite mount.DevPath with
-					// socket FD number so must come after starting virtiofsd).
-					err = func() error {
-						// Check if we should start 9p.
-						if busOption != "auto" && busOption != "9p" {
-							return nil
-						}
-
-						sockFile, cleanup, err := DiskVMVirtfsProxyStart(d.state.OS.ExecPath, d.vmVirtfsProxyHelperPaths(), mount.DevPath, rawIDMaps.Entries)
-						if err != nil {
-							return err
-						}
-
-						revert.Add(cleanup)
-
-						// Request the unix socket is closed after QEMU has connected on startup.
-						runConf.PostHooks = append(runConf.PostHooks, sockFile.Close)
-
-						// Use 9p socket FD number as dev path so qemu can connect to the proxy.
-						mount.DevPath = fmt.Sprintf("%d", sockFile.Fd())
-
-						return nil
-					}()
-					if err != nil {
-						return nil, fmt.Errorf("Failed to setup virtfs-proxy-helper for device %q: %w", d.name, err)
+				// If an idmap is specified, disable 9p.
+				if len(rawIDMaps.Entries) > 0 {
+					// If we are 9p-only, return an error.
+					if busOption == "9p" {
+						return nil, fmt.Errorf("9p shares do not support identity mapping")
 					}
+
+					mount.Opts = append(mount.Opts, "bus=virtiofs")
 				}
 			} else {
 				// Confirm we're dealing with block options.
-				err := validate.Optional(validate.IsOneOf("nvme", "virtio-blk", "virtio-scsi"))(d.config["io.bus"])
+				err := validate.Optional(validate.IsOneOf("nvme", "virtio-blk", "virtio-scsi", "usb"))(d.config["io.bus"])
 				if err != nil {
 					return nil, err
 				}
@@ -1891,7 +1864,7 @@ func (d *disk) createDevice(srcPath string) (func(), string, bool, error) {
 
 	// Create the devices directory if missing.
 	if !util.PathExists(d.inst.DevicesPath()) {
-		err := os.Mkdir(d.inst.DevicesPath(), 0711)
+		err := os.Mkdir(d.inst.DevicesPath(), 0o711)
 		if err != nil {
 			return nil, "", false, err
 		}
@@ -1914,7 +1887,7 @@ func (d *disk) createDevice(srcPath string) (func(), string, bool, error) {
 
 		_ = f.Close()
 	} else {
-		err := os.Mkdir(devPath, 0700)
+		err := os.Mkdir(devPath, 0o700)
 		if err != nil {
 			return nil, "", false, err
 		}
@@ -2178,14 +2151,8 @@ func (d *disk) Stop() (*deviceConfig.RunConfig, error) {
 }
 
 func (d *disk) stopVM() (*deviceConfig.RunConfig, error) {
-	// Stop the virtfs-proxy-helper process and clean up.
-	err := DiskVMVirtfsProxyStop(d.vmVirtfsProxyHelperPaths())
-	if err != nil {
-		return &deviceConfig.RunConfig{}, fmt.Errorf("Failed cleaning up virtfs-proxy-helper: %w", err)
-	}
-
 	// Stop the virtiofsd process and clean up.
-	err = DiskVMVirtiofsdStop(d.vmVirtiofsdPaths())
+	err := DiskVMVirtiofsdStop(d.vmVirtiofsdPaths())
 	if err != nil {
 		return &deviceConfig.RunConfig{}, fmt.Errorf("Failed cleaning up virtiofsd: %w", err)
 	}
@@ -2240,6 +2207,7 @@ func (d *disk) getDiskLimits() (map[string]diskBlockLimit, error) {
 
 	// Build a list of all valid block devices
 	validBlocks := []string{}
+	parentBlocks := map[string]string{}
 
 	dents, err := os.ReadDir("/sys/class/block/")
 	if err != nil {
@@ -2248,10 +2216,13 @@ func (d *disk) getDiskLimits() (map[string]diskBlockLimit, error) {
 
 	for _, f := range dents {
 		fPath := filepath.Join("/sys/class/block/", f.Name())
+
+		// Ignore partitions.
 		if util.PathExists(fmt.Sprintf("%s/partition", fPath)) {
 			continue
 		}
 
+		// Only select real block devices.
 		if !util.PathExists(fmt.Sprintf("%s/dev", fPath)) {
 			continue
 		}
@@ -2261,7 +2232,37 @@ func (d *disk) getDiskLimits() (map[string]diskBlockLimit, error) {
 			return nil, err
 		}
 
-		validBlocks = append(validBlocks, strings.TrimSuffix(string(block), "\n"))
+		// Add the block to the list.
+		blockIdentifier := strings.TrimSuffix(string(block), "\n")
+		validBlocks = append(validBlocks, blockIdentifier)
+
+		// Look for partitions.
+		subDents, err := os.ReadDir(fPath)
+		if err != nil {
+			return nil, err
+		}
+
+		for _, sub := range subDents {
+			// Skip files.
+			if !sub.IsDir() {
+				continue
+			}
+
+			// Select partitions.
+			if !util.PathExists(filepath.Join(fPath, sub.Name(), "partition")) {
+				continue
+			}
+
+			// Get the block identifier for the partition.
+			partition, err := os.ReadFile(filepath.Join(fPath, sub.Name(), "dev"))
+			if err != nil {
+				return nil, err
+			}
+
+			// Add the partition to the map.
+			partitionIdentifier := strings.TrimSuffix(string(partition), "\n")
+			parentBlocks[partitionIdentifier] = blockIdentifier
+		}
 	}
 
 	// Process all the limits
@@ -2310,6 +2311,9 @@ func (d *disk) getDiskLimits() (map[string]diskBlockLimit, error) {
 			if slices.Contains(validBlocks, block) {
 				// Straightforward entry (full block device)
 				blockStr = block
+			} else if parentBlocks[block] != "" {
+				// Known partition.
+				blockStr = parentBlocks[block]
 			} else {
 				// Attempt to deal with a partition (guess its parent)
 				fields := strings.SplitN(block, ":", 2)
@@ -2602,7 +2606,7 @@ func (d *disk) generateVMAgentDrive() (string, error) {
 	}
 
 	// Create agent drive dir.
-	err = os.MkdirAll(scratchDir, 0100)
+	err = os.MkdirAll(scratchDir, 0o100)
 	if err != nil {
 		return "", err
 	}
@@ -2625,7 +2629,7 @@ func (d *disk) generateVMAgentDrive() (string, error) {
 			return "", err
 		}
 
-		err = os.Chmod(agentInstallPath, 0500)
+		err = os.Chmod(agentInstallPath, 0o500)
 		if err != nil {
 			return "", err
 		}
@@ -2660,7 +2664,7 @@ func (d *disk) generateVMConfigDrive() (string, error) {
 	}
 
 	// Create config drive dir.
-	err = os.MkdirAll(scratchDir, 0100)
+	err = os.MkdirAll(scratchDir, 0o100)
 	if err != nil {
 		return "", err
 	}
@@ -2676,7 +2680,7 @@ func (d *disk) generateVMConfigDrive() (string, error) {
 		}
 	}
 
-	err = os.WriteFile(filepath.Join(scratchDir, "vendor-data"), []byte(vendorData), 0400)
+	err = os.WriteFile(filepath.Join(scratchDir, "vendor-data"), []byte(vendorData), 0o400)
 	if err != nil {
 		return "", err
 	}
@@ -2690,7 +2694,7 @@ func (d *disk) generateVMConfigDrive() (string, error) {
 		}
 	}
 
-	err = os.WriteFile(filepath.Join(scratchDir, "user-data"), []byte(userData), 0400)
+	err = os.WriteFile(filepath.Join(scratchDir, "user-data"), []byte(userData), 0o400)
 	if err != nil {
 		return "", err
 	}
@@ -2702,7 +2706,7 @@ func (d *disk) generateVMConfigDrive() (string, error) {
 	}
 
 	if networkConfig != "" {
-		err = os.WriteFile(filepath.Join(scratchDir, "network-config"), []byte(networkConfig), 0400)
+		err = os.WriteFile(filepath.Join(scratchDir, "network-config"), []byte(networkConfig), 0o400)
 		if err != nil {
 			return "", err
 		}
@@ -2714,7 +2718,7 @@ local-hostname: %s
 %s
 `, d.inst.Name(), d.inst.Name(), instanceConfig["user.meta-data"])
 
-	err = os.WriteFile(filepath.Join(scratchDir, "meta-data"), []byte(metaData), 0400)
+	err = os.WriteFile(filepath.Join(scratchDir, "meta-data"), []byte(metaData), 0o400)
 	if err != nil {
 		return "", err
 	}
