@@ -4,7 +4,6 @@ import (
 	"fmt"
 	"net"
 	"strings"
-	"sync"
 	"time"
 
 	"github.com/miekg/dns"
@@ -15,13 +14,12 @@ import (
 
 type dnsHandler struct {
 	server *Server
-	mu     sync.Mutex
 }
 
 func (d dnsHandler) ServeDNS(w dns.ResponseWriter, r *dns.Msg) {
-	// Don't allow concurent queries.
-	d.mu.Lock()
-	defer d.mu.Unlock()
+	// Don't allow concurrent queries.
+	d.server.mu.Lock()
+	defer d.server.mu.Unlock()
 
 	// Check if we're ready to serve queries.
 	if d.server.zoneRetriever == nil {
