@@ -12,9 +12,9 @@ import (
 	"strings"
 	"sync"
 
-	"github.com/lxc/incus/v6/internal/revert"
 	"github.com/lxc/incus/v6/internal/server/project"
 	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/revert"
 	"github.com/lxc/incus/v6/shared/subprocess"
 	"github.com/lxc/incus/v6/shared/util"
 )
@@ -32,7 +32,7 @@ const iptablesCommentPrefix = "generated for"
 // As its own locking mechanism isn't always available.
 var ebtablesMu sync.Mutex
 
-// Xtables is an implmentation of Incus firewall using {ip, ip6, eb}tables.
+// Xtables is an implementation of Incus firewall using {ip, ip6, eb}tables.
 type Xtables struct{}
 
 // String returns the driver name.
@@ -171,7 +171,7 @@ func (d Xtables) networkForwardIPTablesComment(networkName string) string {
 
 // networkSetupNICFilteringChain creates the NIC filtering chain if it doesn't exist, and adds the jump rules to
 // the INPUT and FORWARD filter chains. Must be called after networkSetupForwardingPolicy so that the rules are
-// prepended before the default fowarding policy rules.
+// prepended before the default forwarding policy rules.
 func (d Xtables) networkSetupNICFilteringChain(networkName string, ipVersion uint) error {
 	chain := fmt.Sprintf("%s_%s", iptablesChainNICFilterPrefix, networkName)
 
@@ -233,8 +233,8 @@ func (d Xtables) networkSetupACLFilteringChains(networkName string) error {
 		}
 
 		// Prepend baseline services rules for network.
-		// Unlike OVN networks, we add the rules first before the ACL candidate rules, aa we can't
-		// indentify "INPUT" and "OUTPUT" chain traffic once we have jumped into the ACL chain. At this
+		// Unlike OVN networks, we add the rules first before the ACL candidate rules, as we can't
+		// identify "INPUT" and "OUTPUT" chain traffic once we have jumped into the ACL chain. At this
 		// point it becomes indistinguishable from FORWARD traffic. So unlike OVN an ACL rule cannot be
 		// used to block baseline service traffic.
 
@@ -335,7 +335,6 @@ func (d Xtables) networkSetupForwardingPolicy(networkName string, ipVersion uint
 	}
 
 	err = d.iptablesPrepend(ipVersion, comment, "filter", "FORWARD", "-o", networkName, "-j", forwardType)
-
 	if err != nil {
 		return err
 	}
@@ -390,7 +389,8 @@ func (d Xtables) networkSetupICMPDHCPDNSAccess(networkName string, ipVersion uin
 			{"4", networkName, "filter", "INPUT", "-i", networkName, "-p", "tcp", "--dport", "53", "-j", "ACCEPT"},
 			{"4", networkName, "filter", "OUTPUT", "-o", networkName, "-p", "udp", "--sport", "67", "-j", "ACCEPT"},
 			{"4", networkName, "filter", "OUTPUT", "-o", networkName, "-p", "udp", "--sport", "53", "-j", "ACCEPT"},
-			{"4", networkName, "filter", "OUTPUT", "-o", networkName, "-p", "tcp", "--sport", "53", "-j", "ACCEPT"}}
+			{"4", networkName, "filter", "OUTPUT", "-o", networkName, "-p", "tcp", "--sport", "53", "-j", "ACCEPT"},
+		}
 
 		// Allow core ICMPv4 to/from Incus host.
 		for _, icmpType := range []int{3, 11, 12} {
@@ -404,7 +404,8 @@ func (d Xtables) networkSetupICMPDHCPDNSAccess(networkName string, ipVersion uin
 			{"6", networkName, "filter", "INPUT", "-i", networkName, "-p", "tcp", "--dport", "53", "-j", "ACCEPT"},
 			{"6", networkName, "filter", "OUTPUT", "-o", networkName, "-p", "udp", "--sport", "547", "-j", "ACCEPT"},
 			{"6", networkName, "filter", "OUTPUT", "-o", networkName, "-p", "udp", "--sport", "53", "-j", "ACCEPT"},
-			{"6", networkName, "filter", "OUTPUT", "-o", networkName, "-p", "tcp", "--sport", "53", "-j", "ACCEPT"}}
+			{"6", networkName, "filter", "OUTPUT", "-o", networkName, "-p", "tcp", "--sport", "53", "-j", "ACCEPT"},
+		}
 
 		// Allow core ICMPv6 to/from Incus host.
 		for _, icmpType := range []int{1, 2, 3, 4, 133, 135, 136, 143} {
@@ -810,7 +811,11 @@ func (d Xtables) instanceDeviceIPTablesComment(projectName string, instanceName
 // If the parent bridge is managed by Incus then parentManaged argument should be true so that the rules added can
 // use the iptablesChainACLFilterPrefix chain. If not they are added to the main filter chains directly (which only
 // works for unmanaged bridges because those don't support ACLs).
-func (d Xtables) InstanceSetupBridgeFilter(projectName string, instanceName string, deviceName string, parentName string, hostName string, hwAddr string, IPv4Nets []*net.IPNet, IPv6Nets []*net.IPNet, parentManaged bool) error {
+func (d Xtables) InstanceSetupBridgeFilter(projectName string, instanceName string, deviceName string, parentName string, hostName string, hwAddr string, IPv4Nets []*net.IPNet, IPv6Nets []*net.IPNet, parentManaged bool, macFiltering bool, aclRules []ACLRule) error {
+	if len(aclRules) > 0 {
+		return fmt.Errorf("ACL rules not supported for xtables bridge filtering")
+	}
+
 	comment := d.instanceDeviceIPTablesComment(projectName, instanceName, deviceName)
 
 	rules := d.generateFilterEbtablesRules(hostName, hwAddr, IPv4Nets, IPv6Nets)
@@ -1280,7 +1285,7 @@ func (d Xtables) iptablesClear(ipVersion uint, comments []string, fromTables ...
 		if err != nil {
 			logger.Warnf("Failed getting list of tables from %q, assuming all requested tables exist", tablesFile)
 		} else {
-			tables = []string{} // Initialize the tables slice indcating we were able to open the tables file.
+			tables = []string{} // Initialize the tables slice indicating we were able to open the tables file.
 			scanner := bufio.NewScanner(file)
 			for scanner.Scan() {
 				tables = append(tables, scanner.Text())
