@@ -6,6 +6,15 @@ import (
 	"github.com/lxc/incus/v6/internal/server/firewall/drivers"
 )
 
+// FirewallRules represents a set of firewall rules.
+type FirewallRules struct {
+	Rules         []drivers.ACLRule
+	IngressAction string
+	IngressLogged bool
+	EgressAction  string
+	EgressLogged  bool
+}
+
 // Firewall represents an Incus firewall.
 type Firewall interface {
 	String() string
@@ -16,7 +25,7 @@ type Firewall interface {
 	NetworkApplyACLRules(networkName string, rules []drivers.ACLRule) error
 	NetworkApplyForwards(networkName string, rules []drivers.AddressForward) error
 
-	InstanceSetupBridgeFilter(projectName string, instanceName string, deviceName string, parentName string, hostName string, hwAddr string, IPv4Nets []*net.IPNet, IPv6Nets []*net.IPNet, parentManaged bool) error
+	InstanceSetupBridgeFilter(projectName string, instanceName string, deviceName string, parentName string, hostName string, hwAddr string, IPv4Nets []*net.IPNet, IPv6Nets []*net.IPNet, parentManaged bool, macFiltering bool, aclRules []drivers.ACLRule) error
 	InstanceClearBridgeFilter(projectName string, instanceName string, deviceName string, parentName string, hostName string, hwAddr string, IPv4Nets []*net.IPNet, IPv6Nets []*net.IPNet) error
 
 	InstanceSetupProxyNAT(projectName string, instanceName string, deviceName string, forward *drivers.AddressForward) error
