@@ -1,9 +1,11 @@
 package drivers
 
 import (
+	"cmp"
 	"context"
 	"errors"
 	"fmt"
+	"math"
 	"net/http"
 	"os"
 	"path/filepath"
@@ -43,8 +45,10 @@ import (
 )
 
 // Track last autorestart of an instance.
-var instancesLastRestart = map[int][10]time.Time{}
-var muInstancesLastRestart sync.Mutex
+var (
+	instancesLastRestart   = map[int][10]time.Time{}
+	muInstancesLastRestart sync.Mutex
+)
 
 // ErrExecCommandNotFound indicates the command is not found.
 var ErrExecCommandNotFound = api.StatusErrorf(http.StatusBadRequest, "Command not found")
@@ -598,7 +602,8 @@ func (d *common) restartCommon(inst instance.Instance, timeout time.Duration) er
 		"created":   d.creationDate,
 		"ephemeral": ephemeral,
 		"used":      d.lastUsedDate,
-		"timeout":   timeout}
+		"timeout":   timeout,
+	}
 
 	d.logger.Info("Restarting instance", ctxMap)
 
@@ -649,8 +654,13 @@ func (d *common) restartCommon(inst instance.Instance, timeout time.Duration) er
 	}
 
 	// Setup a new operation for the start phase.
-	op, err = operationlock.Create(d.Project().Name, d.Name(), d.op, operationlock.ActionRestart, true, true)
+	op, err = operationlock.CreateWaitGet(d.Project().Name, d.Name(), d.op, operationlock.ActionRestart, nil, true, false)
 	if err != nil {
+		if errors.Is(err, operationlock.ErrNonReusuableSucceeded) {
+			// An existing matching operation has now succeeded, return.
+			return nil
+		}
+
 		return fmt.Errorf("Create restart (for start) operation: %w", err)
 	}
 
@@ -750,7 +760,7 @@ func (d *common) runHooks(hooks []func() error) error {
 	return nil
 }
 
-// snapshot handles the common part of the snapshoting process.
+// snapshot handles the common part of the snapshotting process.
 func (d *common) snapshotCommon(inst instance.Instance, name string, expiry time.Time, stateful bool) error {
 	revert := revert.New()
 	defer revert.Fail()
@@ -1201,7 +1211,7 @@ func (d *common) deviceLoad(inst instance.Instance, deviceName string, rawConfig
 			return nil, err
 		}
 	} else {
-		// Othewise copy the config so it cannot be modified by device.
+		// Otherwise copy the config so it cannot be modified by device.
 		configCopy = rawConfig.Clone()
 	}
 
@@ -1499,8 +1509,8 @@ func (d *common) deleteSnapshots(deleteFunc func(snapInst instance.Instance) err
 	return nil
 }
 
-// setNUMANode looks at all other instances and picks the least used NUMA node.
-func (d *common) setNUMANode() error {
+// balanceNUMANodes looks at all other instances and picks the least used NUMA node(s).
+func (d *common) balanceNUMANodes() error {
 	muNUMA.Lock()
 	defer muNUMA.Unlock()
 
@@ -1564,19 +1574,38 @@ func (d *common) setNUMANode() error {
 		}
 	}
 
-	// Pick least used node.
-	var node uint64
-	for _, numaNode := range nodes {
-		if numaUsage[int64(numaNode)] < numaUsage[int64(node)] {
-			node = numaNode
+	// Sort NUMA nodes by usage.
+	slices.SortFunc(nodes, func(i, j uint64) int {
+		return cmp.Compare(numaUsage[int64(i)], numaUsage[int64(j)])
+	})
+
+	// If `limits.cpu` is greater than the number of CPUs per NUMA node,
+	// then figure out how many NUMA nodes to use.
+	conf := d.ExpandedConfig()
+	cpusPerNumaNode := int(cpu.Total) / len(nodes)
+
+	limitsCPU, err := strconv.Atoi(conf["limits.cpu"])
+	if err == nil && limitsCPU > cpusPerNumaNode {
+		numaNodesToUse := int(math.Ceil(float64(limitsCPU) / float64(cpusPerNumaNode)))
+
+		selectedNumaNodes := make([]string, numaNodesToUse)
+		for i, node := range nodes[:numaNodesToUse] {
+			selectedNumaNodes[i] = strconv.FormatUint(node, 10)
 		}
+
+		joinedNumaNodes := strings.Join(selectedNumaNodes, ",")
+		return d.VolatileSet(map[string]string{"volatile.cpu.nodes": joinedNumaNodes})
 	}
 
-	return d.VolatileSet(map[string]string{"volatile.cpu.nodes": fmt.Sprintf("%d", node)})
+	return d.VolatileSet(map[string]string{"volatile.cpu.nodes": fmt.Sprintf("%d", nodes[0])})
 }
 
 // Gets the process starting time.
 func (d *common) processStartedAt(pid int) (time.Time, error) {
+	if pid < 1 {
+		return time.Time{}, fmt.Errorf("Invalid PID %q", pid)
+	}
+
 	file, err := os.Stat(fmt.Sprintf("/proc/%d", pid))
 	if err != nil {
 		return time.Time{}, err
