@@ -6,6 +6,7 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/lxc/incus/v6/internal/server/instance/drivers/cfg"
 	"github.com/lxc/incus/v6/shared/osarch"
 )
 
@@ -16,7 +17,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 		return strings.TrimSpace(indent.ReplaceAllString(s, "$1"))
 	}
 
-	runTest := func(expected string, sections []cfgSection) {
+	runTest := func(expected string, sections []cfg.Section) {
 		t.Run(expected, func(t *testing.T) {
 			actual := normalize(qemuStringifyCfg(sections...).String())
 			expected = normalize(expected)
@@ -47,7 +48,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 			[global]
 			driver = "ICH9-LPC"
 			property = "disable_s4"
-			value = "1"
+			value = "0"
 
 			[boot-opts]
 			strict = "on"`,
@@ -701,19 +702,15 @@ func TestQemuConfigTemplates(t *testing.T) {
 
 	t.Run("qemu_console", func(t *testing.T) {
 		testCases := []struct {
-			opts     qemuConsoleOpts
 			expected string
 		}{{
-			qemuConsoleOpts{"/dev/shm/console-socket"},
 			`# Console
 			[chardev "console"]
-			backend = "socket"
-			path = "/dev/shm/console-socket"
-			server = "on"
-			wait = "off"`,
+			backend = "ringbuf"
+			size = "1048576"`,
 		}}
 		for _, tc := range testCases {
-			runTest(tc.expected, qemuConsole(&tc.opts))
+			runTest(tc.expected, qemuConsole())
 		}
 	})
 
@@ -843,15 +840,16 @@ func TestQemuConfigTemplates(t *testing.T) {
 				dev:      qemuDevOpts{"pci", "qemu_pcie0", "00.5", true},
 				devName:  "stub",
 				mountTag: "mtag",
+				path:     "/var/9p",
 				protocol: "9p",
 				readonly: false,
-				proxyFD:  5,
 			},
 			`# stub drive (9p)
 			[fsdev "incus_stub"]
-			fsdriver = "proxy"
-			sock_fd = "5"
+			fsdriver = "local"
+			security_model = "passthrough"
 			readonly = "off"
+			path = "/var/9p"
 
 			[device "dev-incus_stub-9p"]
 			driver = "virtio-9p-pci"
@@ -902,15 +900,16 @@ func TestQemuConfigTemplates(t *testing.T) {
 				dev:      qemuDevOpts{"ccw", "qemu_pcie0", "00.0", false},
 				devName:  "stub2",
 				mountTag: "mtag2",
+				path:     "/var/9p",
 				protocol: "9p",
 				readonly: true,
-				proxyFD:  3,
 			},
 			`# stub2 drive (9p)
 			[fsdev "incus_stub2"]
-			fsdriver = "proxy"
-			sock_fd = "3"
+			fsdriver = "local"
+			security_model = "passthrough"
 			readonly = "on"
+			path = "/var/9p"
 
 			[device "dev-incus_stub2-9p"]
 			driver = "virtio-9p-ccw"
@@ -1086,47 +1085,47 @@ func TestQemuConfigTemplates(t *testing.T) {
 	})
 
 	t.Run("qemu_raw_cfg_override", func(t *testing.T) {
-		cfg := []cfgSection{{
-			name: "global",
-			entries: []cfgEntry{
-				{key: "driver", value: "ICH9-LPC"},
-				{key: "property", value: "disable_s3"},
-				{key: "value", value: "1"},
+		conf := []cfg.Section{{
+			Name: "global",
+			Entries: []cfg.Entry{
+				{Key: "driver", Value: "ICH9-LPC"},
+				{Key: "property", Value: "disable_s3"},
+				{Key: "value", Value: "1"},
 			},
 		}, {
-			name: "global",
-			entries: []cfgEntry{
-				{key: "driver", value: "ICH9-LPC"},
-				{key: "property", value: "disable_s4"},
-				{key: "value", value: "1"},
+			Name: "global",
+			Entries: []cfg.Entry{
+				{Key: "driver", Value: "ICH9-LPC"},
+				{Key: "property", Value: "disable_s4"},
+				{Key: "value", Value: "0"},
 			},
 		}, {
-			name: "memory",
-			entries: []cfgEntry{
-				{key: "size", value: "1024M"},
+			Name: "memory",
+			Entries: []cfg.Entry{
+				{Key: "size", Value: "1024M"},
 			},
 		}, {
-			name: `device "qemu_gpu"`,
-			entries: []cfgEntry{
-				{key: "driver", value: "virtio-gpu-pci"},
-				{key: "bus", value: "qemu_pci3"},
-				{key: "addr", value: "00.0"},
+			Name: `device "qemu_gpu"`,
+			Entries: []cfg.Entry{
+				{Key: "driver", Value: "virtio-gpu-pci"},
+				{Key: "bus", Value: "qemu_pci3"},
+				{Key: "addr", Value: "00.0"},
 			},
 		}, {
-			name: `device "qemu_keyboard"`,
-			entries: []cfgEntry{
-				{key: "driver", value: "virtio-keyboard-pci"},
-				{key: "bus", value: "qemu_pci2"},
-				{key: "addr", value: "00.1"},
+			Name: `device "qemu_keyboard"`,
+			Entries: []cfg.Entry{
+				{Key: "driver", Value: "virtio-keyboard-pci"},
+				{Key: "bus", Value: "qemu_pci2"},
+				{Key: "addr", Value: "00.1"},
 			},
 		}}
 		testCases := []struct {
-			cfg       []cfgSection
+			cfg       []cfg.Section
 			overrides map[string]string
 			expected  string
 		}{{
 			// unmodified
-			cfg,
+			conf,
 			map[string]string{},
 			`[global]
 			driver = "ICH9-LPC"
@@ -1136,7 +1135,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 			[global]
 			driver = "ICH9-LPC"
 			property = "disable_s4"
-			value = "1"
+			value = "0"
 
 			[memory]
 			size = "1024M"
@@ -1152,7 +1151,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 			addr = "00.1"`,
 		}, {
 			// override some keys
-			cfg,
+			conf,
 			map[string]string{
 				"raw.qemu.conf": `
 						[memory]
@@ -1169,7 +1168,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 			[global]
 			driver = "ICH9-LPC"
 			property = "disable_s4"
-			value = "1"
+			value = "0"
 
 			[memory]
 			size = "4096M"
@@ -1185,7 +1184,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 			addr = "00.1"`,
 		}, {
 			// delete some keys
-			cfg,
+			conf,
 			map[string]string{
 				"raw.qemu.conf": `
 						[device "qemu_keyboard"]
@@ -1202,7 +1201,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				[global]
 				driver = "ICH9-LPC"
 				property = "disable_s4"
-				value = "1"
+				value = "0"
 
 				[memory]
 				size = "1024M"
@@ -1216,7 +1215,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				addr = "00.1"`,
 		}, {
 			// add some keys to existing sections
-			cfg,
+			conf,
 			map[string]string{
 				"raw.qemu.conf": `
 						[memory]
@@ -1239,7 +1238,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				[global]
 				driver = "ICH9-LPC"
 				property = "disable_s4"
-				value = "1"
+				value = "0"
 
 				[memory]
 				size = "1024M"
@@ -1261,7 +1260,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				multifunction = "off"`,
 		}, {
 			// edit/add/remove
-			cfg,
+			conf,
 			map[string]string{
 				"raw.qemu.conf": `
 						[memory]
@@ -1280,7 +1279,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				[global]
 				driver = "ICH9-LPC"
 				property = "disable_s4"
-				value = "1"
+				value = "0"
 
 				[memory]
 				size = "2048M"
@@ -1295,7 +1294,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				driver = "virtio-keyboard-pci"`,
 		}, {
 			// delete sections
-			cfg,
+			conf,
 			map[string]string{
 				"raw.qemu.conf": `
 						[memory]
@@ -1313,7 +1312,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				addr = "00.0"`,
 		}, {
 			// add sections
-			cfg,
+			conf,
 			map[string]string{
 				"raw.qemu.conf": `
 						[object1]
@@ -1339,7 +1338,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				[global]
 				driver = "ICH9-LPC"
 				property = "disable_s4"
-				value = "1"
+				value = "0"
 
 				[memory]
 				size = "1024M"
@@ -1367,7 +1366,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				key6 = "value6"`,
 		}, {
 			// add/remove sections
-			cfg,
+			conf,
 			map[string]string{
 				"raw.qemu.conf": `
 						[device "qemu_gpu"]
@@ -1386,7 +1385,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				[global]
 				driver = "ICH9-LPC"
 				property = "disable_s4"
-				value = "1"
+				value = "0"
 
 				[memory]
 				size = "1024M"
@@ -1404,7 +1403,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				key4 = "value4"`,
 		}, {
 			// edit keys of repeated sections
-			cfg,
+			conf,
 			map[string]string{
 				"raw.qemu.conf": `
 						[global][1]
@@ -1443,7 +1442,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				addr = "00.1"`,
 		}, {
 			// create multiple sections with same name
-			cfg,
+			conf,
 			// note that for appending new sections, all that matters is that
 			// the index is higher than the existing indexes
 			map[string]string{
@@ -1471,7 +1470,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				[global]
 				driver = "ICH9-LPC"
 				property = "disable_s4"
-				value = "1"
+				value = "0"
 
 				[memory]
 				size = "1024M"
@@ -1502,7 +1501,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				k11 = "v11"`,
 		}, {
 			// mix all operations
-			cfg,
+			conf,
 			map[string]string{
 				"raw.qemu.conf": `
 						[memory]
@@ -1526,7 +1525,7 @@ func TestQemuConfigTemplates(t *testing.T) {
 				[global]
 				driver = "ICH9-LPC"
 				property = "disable_s4"
-				value = "1"
+				value = "0"
 
 				[memory]
 				size = "8192M"
