@@ -4,8 +4,8 @@ import (
 	"net"
 	"strings"
 
-	"github.com/lxc/incus/shared/subprocess"
-	"github.com/lxc/incus/shared/util"
+	"github.com/lxc/incus/v6/shared/subprocess"
+	"github.com/lxc/incus/v6/shared/util"
 )
 
 // NeighProxy represents arguments for neighbour proxy manipulation.
