@@ -183,6 +183,7 @@ func (n *bridge) Validate(config map[string]string) error {
 		"ipv4.dhcp.gateway": validate.Optional(validate.IsNetworkAddressV4),
 		"ipv4.dhcp.expiry":  validate.IsAny,
 		"ipv4.dhcp.ranges":  validate.Optional(validate.IsListOf(validate.IsNetworkRangeV4)),
+		"ipv4.dhcp.routes":  validate.Optional(validate.IsDHCPRouteList),
 		"ipv4.routes":       validate.Optional(validate.IsListOf(validate.IsNetworkV4)),
 		"ipv4.routing":      validate.Optional(validate.IsBool),
 		"ipv4.ovn.ranges":   validate.Optional(validate.IsListOf(validate.IsNetworkRangeV4)),
@@ -205,6 +206,7 @@ func (n *bridge) Validate(config map[string]string) error {
 		"ipv6.routes":                          validate.Optional(validate.IsListOf(validate.IsNetworkV6)),
 		"ipv6.routing":                         validate.Optional(validate.IsBool),
 		"ipv6.ovn.ranges":                      validate.Optional(validate.IsListOf(validate.IsNetworkRangeV6)),
+		"dns.nameservers":                      validate.Optional(validate.IsListOf(validate.IsNetworkAddress)),
 		"dns.domain":                           validate.IsAny,
 		"dns.mode":                             validate.Optional(validate.IsOneOf("dynamic", "managed", "none")),
 		"dns.search":                           validate.IsAny,
@@ -273,7 +275,7 @@ func (n *bridge) Validate(config map[string]string) error {
 		return err
 	}
 
-	// Peform composite key checks after per-key validation.
+	// Perform composite key checks after per-key validation.
 
 	// Validate DNS zone names.
 	err = n.validateZoneNames(config)
@@ -511,7 +513,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 
 	// Create directory.
 	if !util.PathExists(internalUtil.VarPath("networks", n.name)) {
-		err := os.MkdirAll(internalUtil.VarPath("networks", n.name), 0711)
+		err := os.MkdirAll(internalUtil.VarPath("networks", n.name), 0o711)
 		if err != nil {
 			return err
 		}
@@ -634,7 +636,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 	}
 
 	// IPv6 bridge configuration.
-	if !slices.Contains([]string{"", "none"}, n.config["ipv6.address"]) {
+	if !util.IsNoneOrEmpty(n.config["ipv6.address"]) {
 		if !util.PathExists("/proc/sys/net/ipv6") {
 			return fmt.Errorf("Network has ipv6.address but kernel IPv6 support is missing")
 		}
@@ -665,21 +667,9 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 		}
 	}
 
-	// Get a list of interfaces.
-	ifaces, err := net.Interfaces()
+	err = n.deleteChildren()
 	if err != nil {
-		return err
-	}
-
-	// Cleanup any existing tunnel device.
-	for _, iface := range ifaces {
-		if strings.HasPrefix(iface.Name, fmt.Sprintf("%s-", n.name)) {
-			tunLink := &ip.Link{Name: iface.Name}
-			err = tunLink.Delete()
-			if err != nil {
-				return err
-			}
-		}
+		return fmt.Errorf("Failed to delete bridge children interfaces: %w", err)
 	}
 
 	// Attempt to add a dummy device to the bridge to force the MTU.
@@ -860,7 +850,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 	}
 
 	// Configure IPv4 firewall.
-	if !slices.Contains([]string{"", "none"}, n.config["ipv4.address"]) {
+	if !util.IsNoneOrEmpty(n.config["ipv4.address"]) {
 		if n.hasDHCPv4() && n.hasIPv4Firewall() {
 			fwOpts.FeaturesV4.ICMPDHCPDNSAccess = true
 		}
@@ -880,11 +870,13 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 
 	// Start building process using subprocess package.
 	command := "dnsmasq"
-	dnsmasqCmd := []string{"--keep-in-foreground", "--strict-order", "--bind-interfaces",
+	dnsmasqCmd := []string{
+		"--keep-in-foreground", "--strict-order", "--bind-interfaces",
 		"--except-interface=lo",
 		"--pid-file=", // Disable attempt at writing a PID file.
 		"--no-ping",   // --no-ping is very important to prevent delays to lease file updates.
-		fmt.Sprintf("--interface=%s", n.name)}
+		fmt.Sprintf("--interface=%s", n.name),
+	}
 
 	dnsmasqVersion, err := dnsmasq.GetVersion()
 	if err != nil {
@@ -912,8 +904,18 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 		}
 	}
 
+	var dnsIPv4 []string
+	var dnsIPv6 []string
+	for _, s := range util.SplitNTrimSpace(n.config["dns.nameservers"], ",", -1, false) {
+		if net.ParseIP(s).To4() != nil {
+			dnsIPv4 = append(dnsIPv4, s)
+		} else {
+			dnsIPv6 = append(dnsIPv6, s)
+		}
+	}
+
 	// Configure IPv4.
-	if !slices.Contains([]string{"", "none"}, n.config["ipv4.address"]) {
+	if !util.IsNoneOrEmpty(n.config["ipv4.address"]) {
 		// Parse the subnet.
 		ipAddress, subnet, err := net.ParseCIDR(n.config["ipv4.address"])
 		if err != nil {
@@ -931,6 +933,14 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 				dnsmasqCmd = append(dnsmasqCmd, fmt.Sprintf("--dhcp-option-force=3,%s", n.config["ipv4.dhcp.gateway"]))
 			}
 
+			if n.config["dns.nameservers"] != "" {
+				if len(dnsIPv4) == 0 {
+					dnsmasqCmd = append(dnsmasqCmd, "--dhcp-option-force=6")
+				} else {
+					dnsmasqCmd = append(dnsmasqCmd, fmt.Sprintf("--dhcp-option-force=6,%s", strings.Join(dnsIPv4, ",")))
+				}
+			}
+
 			if bridge.MTU != bridgeMTUDefault {
 				dnsmasqCmd = append(dnsmasqCmd, fmt.Sprintf("--dhcp-option-force=26,%d", bridge.MTU))
 			}
@@ -940,6 +950,10 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 				dnsmasqCmd = append(dnsmasqCmd, fmt.Sprintf("--dhcp-option-force=119,%s", strings.Trim(dnsSearch, " ")))
 			}
 
+			if n.config["ipv4.dhcp.routes"] != "" {
+				dnsmasqCmd = append(dnsmasqCmd, fmt.Sprintf("--dhcp-option-force=121,%s", strings.ReplaceAll(n.config["ipv4.dhcp.routes"], " ", "")))
+			}
+
 			expiry := "1h"
 			if n.config["ipv4.dhcp.expiry"] != "" {
 				expiry = n.config["ipv4.dhcp.expiry"]
@@ -948,7 +962,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 			if n.config["ipv4.dhcp.ranges"] != "" {
 				for _, dhcpRange := range strings.Split(n.config["ipv4.dhcp.ranges"], ",") {
 					dhcpRange = strings.TrimSpace(dhcpRange)
-					dnsmasqCmd = append(dnsmasqCmd, []string{"--dhcp-range", fmt.Sprintf("%s,%s", strings.Replace(dhcpRange, "-", ",", -1), expiry)}...)
+					dnsmasqCmd = append(dnsmasqCmd, []string{"--dhcp-range", fmt.Sprintf("%s,%s", strings.ReplaceAll(dhcpRange, "-", ","), expiry)}...)
 				}
 			} else {
 				dnsmasqCmd = append(dnsmasqCmd, []string{"--dhcp-range", fmt.Sprintf("%s,%s,%s", dhcpalloc.GetIP(subnet, 2).String(), dhcpalloc.GetIP(subnet, -2).String(), expiry)}...)
@@ -969,7 +983,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 
 		// Configure NAT.
 		if util.IsTrue(n.config["ipv4.nat"]) {
-			//If a SNAT source address is specified, use that, otherwise default to MASQUERADE mode.
+			// If a SNAT source address is specified, use that, otherwise default to MASQUERADE mode.
 			var srcIP net.IP
 			if n.config["ipv4.nat.address"] != "" {
 				srcIP = net.ParseIP(n.config["ipv4.nat.address"])
@@ -1038,7 +1052,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 	}
 
 	// Configure IPv6.
-	if !slices.Contains([]string{"", "none"}, n.config["ipv6.address"]) {
+	if !util.IsNoneOrEmpty(n.config["ipv6.address"]) {
 		// Enable IPv6 for the subnet.
 		err := localUtil.SysctlSet(fmt.Sprintf("net/ipv6/conf/%s/disable_ipv6", n.name), "0")
 		if err != nil {
@@ -1090,7 +1104,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 				if n.config["ipv6.dhcp.ranges"] != "" {
 					for _, dhcpRange := range strings.Split(n.config["ipv6.dhcp.ranges"], ",") {
 						dhcpRange = strings.TrimSpace(dhcpRange)
-						dnsmasqCmd = append(dnsmasqCmd, []string{"--dhcp-range", fmt.Sprintf("%s,%d,%s", strings.Replace(dhcpRange, "-", ",", -1), subnetSize, expiry)}...)
+						dnsmasqCmd = append(dnsmasqCmd, []string{"--dhcp-range", fmt.Sprintf("%s,%d,%s", strings.ReplaceAll(dhcpRange, "-", ","), subnetSize, expiry)}...)
 					}
 				} else {
 					dnsmasqCmd = append(dnsmasqCmd, []string{"--dhcp-range", fmt.Sprintf("%s,%s,%d,%s", dhcpalloc.GetIP(subnet, 2), dhcpalloc.GetIP(subnet, -1), subnetSize, expiry)}...)
@@ -1102,6 +1116,14 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 			dnsmasqCmd = append(dnsmasqCmd, []string{"--dhcp-range", fmt.Sprintf("::,constructor:%s,ra-only", n.name)}...)
 		}
 
+		if n.config["dns.nameservers"] != "" {
+			if len(dnsIPv6) == 0 {
+				dnsmasqCmd = append(dnsmasqCmd, "--dhcp-option-force=option6:dns-server")
+			} else {
+				dnsmasqCmd = append(dnsmasqCmd, fmt.Sprintf("--dhcp-option-force=option6:dns-server,[%s]", strings.Join(dnsIPv6, ",")))
+			}
+		}
+
 		// Allow forwarding.
 		if util.IsTrueOrEmpty(n.config["ipv6.routing"]) {
 			// Get a list of proc entries.
@@ -1158,7 +1180,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 
 		// Configure NAT.
 		if util.IsTrue(n.config["ipv6.nat"]) {
-			//If a SNAT source address is specified, use that, otherwise default to MASQUERADE mode.
+			// If a SNAT source address is specified, use that, otherwise default to MASQUERADE mode.
 			var srcIP net.IP
 			if n.config["ipv6.nat.address"] != "" {
 				srcIP = net.ParseIP(n.config["ipv6.nat.address"])
@@ -1341,7 +1363,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 		}
 
 		// Create a config file to contain additional config (and to prevent dnsmasq from reading /etc/dnsmasq.conf)
-		err = os.WriteFile(internalUtil.VarPath("networks", n.name, "dnsmasq.raw"), []byte(fmt.Sprintf("%s\n", n.config["raw.dnsmasq"])), 0644)
+		err = os.WriteFile(internalUtil.VarPath("networks", n.name, "dnsmasq.raw"), []byte(fmt.Sprintf("%s\n", n.config["raw.dnsmasq"])), 0o644)
 		if err != nil {
 			return err
 		}
@@ -1359,7 +1381,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 
 		// Create DHCP hosts directory.
 		if !util.PathExists(internalUtil.VarPath("networks", n.name, "dnsmasq.hosts")) {
-			err = os.MkdirAll(internalUtil.VarPath("networks", n.name, "dnsmasq.hosts"), 0755)
+			err = os.MkdirAll(internalUtil.VarPath("networks", n.name, "dnsmasq.hosts"), 0o755)
 			if err != nil {
 				return err
 			}
@@ -1503,6 +1525,11 @@ func (n *bridge) Stop() error {
 		return err
 	}
 
+	err = n.deleteChildren()
+	if err != nil {
+		return fmt.Errorf("Failed to delete bridge children interfaces: %w", err)
+	}
+
 	// Destroy the bridge interface
 	if n.config["bridge.driver"] == "openvswitch" {
 		vswitch, err := n.state.OVS()
@@ -1547,23 +1574,6 @@ func (n *bridge) Stop() error {
 		return err
 	}
 
-	// Get a list of interfaces
-	ifaces, err := net.Interfaces()
-	if err != nil {
-		return err
-	}
-
-	// Cleanup any existing tunnel device
-	for _, iface := range ifaces {
-		if strings.HasPrefix(iface.Name, fmt.Sprintf("%s-", n.name)) {
-			tunLink := &ip.Link{Name: iface.Name}
-			err = tunLink.Delete()
-			if err != nil {
-				return err
-			}
-		}
-	}
-
 	// Unload apparmor profiles.
 	err = apparmor.NetworkUnload(n.state.OS, n)
 	if err != nil {
@@ -1767,7 +1777,7 @@ func (n *bridge) applyBootRoutesV6(routes []string) {
 // hasIPv4Firewall indicates whether the network has IPv4 firewall enabled.
 func (n *bridge) hasIPv4Firewall() bool {
 	// IPv4 firewall is only enabled if there is a bridge ipv4.address and ipv4.firewall enabled.
-	if !slices.Contains([]string{"", "none"}, n.config["ipv4.address"]) && util.IsTrueOrEmpty(n.config["ipv4.firewall"]) {
+	if !util.IsNoneOrEmpty(n.config["ipv4.address"]) && util.IsTrueOrEmpty(n.config["ipv4.firewall"]) {
 		return true
 	}
 
@@ -1777,7 +1787,7 @@ func (n *bridge) hasIPv4Firewall() bool {
 // hasIPv6Firewall indicates whether the network has IPv6 firewall enabled.
 func (n *bridge) hasIPv6Firewall() bool {
 	// IPv6 firewall is only enabled if there is a bridge ipv6.address and ipv6.firewall enabled.
-	if !slices.Contains([]string{"", "none"}, n.config["ipv6.address"]) && util.IsTrueOrEmpty(n.config["ipv6.firewall"]) {
+	if !util.IsNoneOrEmpty(n.config["ipv6.address"]) && util.IsTrueOrEmpty(n.config["ipv6.firewall"]) {
 		return true
 	}
 
@@ -2684,5 +2694,65 @@ func (n *bridge) Leases(projectName string, clientType request.ClientType) ([]ap
 
 // UsesDNSMasq indicates if network's config indicates if it needs to use dnsmasq.
 func (n *bridge) UsesDNSMasq() bool {
-	return !slices.Contains([]string{"", "none"}, n.config["ipv4.address"]) || !slices.Contains([]string{"", "none"}, n.config["ipv6.address"])
+	// Skip dnsmasq when no connectivity is configured.
+	if util.IsNoneOrEmpty(n.config["ipv4.address"]) && util.IsNoneOrEmpty(n.config["ipv6.address"]) {
+		return false
+	}
+
+	// Start dnsmasq if providing instance DNS records.
+	if n.config["dns.mode"] != "none" {
+		return true
+	}
+
+	// Start dnsmassq if IPv6 is used (needed for SLAAC or DHCPv6).
+	if !util.IsNoneOrEmpty(n.config["ipv6.address"]) {
+		return true
+	}
+
+	// Start dnsmasq if IPv4 DHCP is used.
+	if !util.IsNoneOrEmpty(n.config["ipv4.address"]) && n.hasDHCPv4() {
+		return true
+	}
+
+	return false
+}
+
+func (n *bridge) deleteChildren() error {
+	// Get a list of interfaces
+	ifaces, err := net.Interfaces()
+	if err != nil {
+		return err
+	}
+
+	var externalInterfaces []string
+	if n.config["bridge.external_interfaces"] != "" {
+		for _, entry := range strings.Split(n.config["bridge.external_interfaces"], ",") {
+			entry = strings.Split(strings.TrimSpace(entry), "/")[0]
+			externalInterfaces = append(externalInterfaces, entry)
+		}
+	}
+
+	kinds := []string{
+		"vxlan",
+		"gretap",
+		"dummy",
+	}
+
+	for _, iface := range ifaces {
+		l, err := ip.LinkFromName(iface.Name)
+		if err != nil {
+			return err
+		}
+
+		if l.Master != n.name || slices.Contains(externalInterfaces, iface.Name) || !slices.Contains(kinds, l.Kind) {
+			continue
+		}
+
+		err = l.Delete()
+		if err != nil {
+			return err
+		}
+	}
+
+	return nil
 }
