@@ -12,5 +12,8 @@ var ErrExists = fmt.Errorf("object already exists")
 // ErrNotFound indicates that a DB record doesn't exist.
 var ErrNotFound = ovsdbClient.ErrNotFound
 
+// ErrTooMany is returned when one match is expected but multiple are found.
+var ErrTooMany = fmt.Errorf("too many objects found")
+
 // ErrNotManaged indicates that a DB record wasn't created by Incus.
 var ErrNotManaged = fmt.Errorf("object not incus-managed")
