@@ -5,8 +5,8 @@ package operations
 import (
 	"fmt"
 
-	"github.com/lxc/incus/internal/server/db/operationtype"
-	"github.com/lxc/incus/shared/api"
+	"github.com/lxc/incus/v6/internal/server/db/operationtype"
+	"github.com/lxc/incus/v6/shared/api"
 )
 
 func registerDBOperation(op *Operation, opType operationtype.Type) error {
