@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	"strconv"
+	"strings"
 
 	"github.com/lxc/incus/v6/internal/server/db"
 	"github.com/lxc/incus/v6/internal/server/instance/instancetype"
@@ -29,6 +30,16 @@ func GetCurrentAllocations(ctx context.Context, tx *db.ClusterTx, projectName st
 		return nil, err
 	}
 
+	// Get per-pool limits.
+	poolLimits := []string{}
+	for k := range info.Project.Config {
+		if strings.HasPrefix(k, projectLimitDiskPool) {
+			poolLimits = append(poolLimits, k)
+		}
+	}
+
+	allAggregateLimits := append(allAggregateLimits, poolLimits...)
+
 	// Get the instance aggregated values.
 	raw, err := getAggregateLimits(info, allAggregateLimits)
 	if err != nil {
@@ -41,6 +52,13 @@ func GetCurrentAllocations(ctx context.Context, tx *db.ClusterTx, projectName st
 	result["networks"] = raw["limits.networks"]
 	result["processes"] = raw["limits.processes"]
 
+	// Add the pool-specific disk limits.
+	for k, v := range raw {
+		if strings.HasPrefix(k, projectLimitDiskPool) && v.Limit > 0 {
+			result[fmt.Sprintf("disk.%s", strings.SplitN(k, ".", 4)[3])] = v
+		}
+	}
+
 	// Get the instance count values.
 	count, limit, err := getTotalInstanceCountLimit(info)
 	if err != nil {
