@@ -15,8 +15,10 @@ const prefixQEMU = "qemu"
 // nameAuthorization is the name used in Starlark for the Authorization scriptlet.
 const nameAuthorization = "authorization"
 
-var programsMu sync.Mutex
-var programs = make(map[string]*starlark.Program)
+var (
+	programsMu sync.Mutex
+	programs   = make(map[string]*starlark.Program)
+)
 
 // InstancePlacementCompile compiles the instance placement scriptlet.
 func InstancePlacementCompile(name string, src string) (*starlark.Program, error) {
@@ -59,6 +61,7 @@ func QEMUCompile(name string, src string) (*starlark.Program, error) {
 		"log_info",
 		"log_warn",
 		"log_error",
+
 		"run_qmp",
 		"run_command",
 		"blockdev_add",
@@ -75,13 +78,18 @@ func QEMUCompile(name string, src string) (*starlark.Program, error) {
 		"qom_get",
 		"qom_list",
 		"qom_set",
+
+		"get_qemu_cmdline",
+		"set_qemu_cmdline",
+		"get_qemu_conf",
+		"set_qemu_conf",
 	})
 }
 
 // QEMUValidate validates the QEMU scriptlet.
 func QEMUValidate(src string) error {
 	return validate(QEMUCompile, prefixQEMU, src, declaration{
-		required("qemu_hook"): {"stage"},
+		required("qemu_hook"): {"instance", "stage"},
 	})
 }
 
