@@ -15,8 +15,10 @@ import (
 	"github.com/lxc/incus/v6/shared/validate"
 )
 
-var cephobjectVersion string
-var cephobjectLoaded bool
+var (
+	cephobjectVersion string
+	cephobjectLoaded  bool
+)
 
 // cephobjectRadosgwAdminUser admin user in radosgw.
 const cephobjectRadosgwAdminUser = "incus-admin"
@@ -199,6 +201,6 @@ func (d *cephobject) GetResources() (*api.ResourcesStoragePool, error) {
 }
 
 // MigrationTypes returns the supported migration types and options supported by the driver.
-func (d *cephobject) MigrationTypes(contentType ContentType, refresh bool, copySnapshots bool) []migration.Type {
+func (d *cephobject) MigrationTypes(contentType ContentType, refresh bool, copySnapshots bool, clusterMove bool, storageMove bool) []migration.Type {
 	return nil
 }
