@@ -102,7 +102,7 @@ type Driver interface {
 	RestoreVolume(vol Volume, snapshotName string, op *operations.Operation) error
 
 	// Migration.
-	MigrationTypes(contentType ContentType, refresh bool, copySnapshots bool) []migration.Type
+	MigrationTypes(contentType ContentType, refresh bool, copySnapshots bool, clusterMove bool, storageMove bool) []migration.Type
 	MigrateVolume(vol Volume, conn io.ReadWriteCloser, volSrcArgs *migration.VolumeSourceArgs, op *operations.Operation) error
 	CreateVolumeFromMigration(vol Volume, conn io.ReadWriteCloser, volTargetArgs migration.VolumeTargetArgs, preFiller *VolumeFiller, op *operations.Operation) error
 
