@@ -3,6 +3,7 @@ package miniod
 import (
 	"bytes"
 	"context"
+	"encoding/base64"
 	"fmt"
 	"net"
 	"net/url"
@@ -42,6 +43,9 @@ const minioAdminUser = "incus-admin"
 // minioBucketDir the directory on the storage volume used for the MinIO bucket.
 const minioBucketDir = "minio"
 
+// mcAliasPrefix is the prefix used for mc aliases, as they have to start with a letter.
+const mcAliasPrefix = "base64url_"
+
 // Process represents a running minio process.
 type Process struct {
 	bucketName   string
@@ -65,25 +69,52 @@ func (p *Process) AdminUser() string {
 
 // AdminClient returns admin client for the minio process.
 func (p *Process) AdminClient() (*AdminClient, error) {
-	binaryName := "mc"
-	_, err := exec.LookPath(binaryName)
-	if err != nil {
-		binaryName = "mcli"
-		_, err = exec.LookPath(binaryName)
+	var binaryName string
+
+	isMinIOClient := func(name string) bool {
+		cmd := exec.Command(name, "--version")
+		b, err := cmd.Output()
 		if err != nil {
-			return nil, err
+			return false
+		}
+
+		lines := strings.Split(string(b), "\n")
+		if len(lines) < 3 {
+			return false
+		}
+
+		if strings.Contains(lines[0], name+" version") &&
+			strings.Contains(lines[2], "MinIO") {
+			return true
+		}
+
+		return false
+	}
+
+	for _, name := range []string{"miniocli", "minioc", "mcli", "minio-client", "mc"} {
+		_, err := exec.LookPath(name)
+		if err != nil {
+			continue
+		}
+
+		if isMinIOClient(name) {
+			binaryName = name
+			break
 		}
 	}
 
-	client := &AdminClient{
-		p,
-		strings.Replace(p.bucketName, ".", "_", -1),
-		binaryName,
-		internalUtil.VarPath(""),
+	if binaryName == "" {
+		return nil, fmt.Errorf("Couldn't find the MinIO client tool")
 	}
 
-	if !client.isMinIOClient() {
-		return nil, fmt.Errorf("'%s' binary is not MinIO client", binaryName)
+	// Encode the bucketName with base64url as only certain characters with alpha prefix are allowed
+	aliasPrefixedEncoded := mcAliasPrefix + base64.RawURLEncoding.EncodeToString([]byte(p.bucketName))
+
+	client := &AdminClient{
+		p,
+		aliasPrefixedEncoded,
+		binaryName,
+		internalUtil.VarPath(""),
 	}
 
 	return client, nil
@@ -175,8 +206,10 @@ func (p *Process) WaitReady(ctx context.Context) error {
 	}
 }
 
-var miniosMu sync.Mutex
-var minios = make(map[string]*Process)
+var (
+	miniosMu sync.Mutex
+	minios   = make(map[string]*Process)
+)
 
 // EnsureRunning starts a MinIO process for the bucket (if not already running) and returns running Process.
 func EnsureRunning(s *state.State, bucketVol storageDrivers.Volume) (*Process, error) {
@@ -250,7 +283,7 @@ func EnsureRunning(s *state.State, bucketVol storageDrivers.Volume) (*Process, e
 		err := bucketVol.MountTask(func(mountPath string, op *operations.Operation) error {
 			l.Debug("MinIO bucket starting")
 
-			var newDirMode os.FileMode = os.ModeDir | 0700
+			newDirMode := os.ModeDir | 0o700
 
 			if !util.PathExists(bucketPath) {
 				err = os.Mkdir(bucketPath, newDirMode)
