@@ -72,12 +72,12 @@ func FileCopy(source string, dest string) error {
 
 	d, err := os.Create(dest)
 	if err != nil {
-		if os.IsExist(err) {
-			d, err = os.OpenFile(dest, os.O_WRONLY, fi.Mode())
-			if err != nil {
-				return err
-			}
-		} else {
+		if !os.IsExist(err) {
+			return err
+		}
+
+		d, err = os.OpenFile(dest, os.O_WRONLY, fi.Mode())
+		if err != nil {
 			return err
 		}
 	}
