@@ -453,6 +453,24 @@ var APIExtensions = []string{
 	"image_import_alias",
 	"authorization_scriptlet",
 	"console_force",
+	"network_ovn_state_addresses",
+	"network_bridge_acl_devices",
+	"instance_debug_memory",
+	"init_preseed_storage_volumes",
+	"init_preseed_profile_project",
+	`instance_nic_routed_host_address`,
+	"instance_smbios11",
+	"api_filtering_extended",
+	"acme_dns01",
+	"security_iommu",
+	"network_ipv4_dhcp_routes",
+	"network_state_ovn_ls",
+	"network_dns_nameservers",
+	"acme_http01_port",
+	"network_ovn_ipv4_dhcp_expiry",
+	"instance_state_cpu_time",
+	"network_io_bus",
+	"disk_io_bus_usb",
 }
 
 // APIExtensionsCount returns the number of available API extensions.
