@@ -17,7 +17,7 @@ import (
 func (c *Config) handleKeepAlive(remote Remote, name string, args *incus.ConnectionArgs) (incus.InstanceServer, error) {
 	// Create the socker directory if missing.
 	socketDir := filepath.Join(c.ConfigDir, "keepalive")
-	err := os.Mkdir(socketDir, 0700)
+	err := os.Mkdir(socketDir, 0o700)
 	if err != nil && !os.IsExist(err) {
 		return nil, err
 	}
