@@ -1,12 +1,14 @@
 package util
 
 import (
+	"errors"
+	"io/fs"
 	"os"
 )
 
 func PathExists(name string) bool {
 	_, err := os.Lstat(name)
-	if err != nil && os.IsNotExist(err) {
+	if err != nil && errors.Is(err, fs.ErrNotExist) {
 		return false
 	}
 
