@@ -34,6 +34,11 @@ test_basic_usage() {
   incus image alias list | grep -qv foo  # the old name is gone
   incus image alias delete bar
 
+  # Test an alias with description
+  incus image alias create baz "${sum}" --description "Test description"
+  incus image alias list | grep -q 'Test description'
+  incus image alias delete baz
+
   # Test image list output formats (table & json)
   incus image list --format table | grep -q testimage
   incus image list --format json \
@@ -102,7 +107,7 @@ test_basic_usage() {
   # Test container creation
   incus init testimage foo
   incus list | grep foo | grep STOPPED
-  incus list fo | grep foo | grep STOPPED
+  incus list fo | grep foo | grep STOPPED  # codespell:ignore fo
 
   # Test list json format
   incus list --format json | jq '.[]|select(.name="foo")' | grep '"name": "foo"'
@@ -373,7 +378,7 @@ test_basic_usage() {
   kill_incus "${INCUS_ACTIVATION_DIR}"
 
   # Create and start a container
-  incus launch testimage foo
+  incus launch testimage foo --description "Test container"
   incus list | grep foo | grep RUNNING
   incus stop foo --force
 
@@ -394,6 +399,18 @@ test_basic_usage() {
   [ "$(incus config get test-limits limits.cpu)" = "1" ]
   [ "$(incus config get test-limits limits.cpu.allowance)" = "50%" ]
   [ "$(incus config get test-limits limits.memory)" = "204MiB" ]
+
+  # Test CPU allocation information
+  [ "$(incus query /1.0/instances/test-limits/state | jq -r '.cpu.allocated_time')" = "1000000000" ]
+  incus config set test-limits limits.cpu.allowance 100ms/200ms
+  [ "$(incus query /1.0/instances/test-limits/state | jq -r '.cpu.allocated_time')" = "500000000" ]
+  incus config set test-limits limits.cpu 2
+  [ "$(incus query /1.0/instances/test-limits/state | jq -r '.cpu.allocated_time')" = "500000000" ]
+  incus config unset test-limits limits.cpu.allowance
+  [ "$(incus query /1.0/instances/test-limits/state | jq -r '.cpu.allocated_time')" = "2000000000" ]
+  incus config unset test-limits limits.cpu
+  [ "$(incus query /1.0/instances/test-limits/state | jq -r '.cpu.allocated_time')" = "$(nproc)000000000" ]
+
   incus delete -f test-limits
 
   # Test last_used_at field is working properly
@@ -435,7 +452,7 @@ test_basic_usage() {
 
   # test incus file edit doesn't change target file's owner and permissions
   echo "content" | incus file push - foo/tmp/edit_test
-  incus exec foo -- chown 55.55 /tmp/edit_test
+  incus exec foo -- chown 55:55 /tmp/edit_test
   incus exec foo -- chmod 555 /tmp/edit_test
   echo "new content" | incus file edit foo/tmp/edit_test
   [ "$(incus exec foo -- cat /tmp/edit_test)" = "new content" ]
